// Kairos WP Plugin - API Calls Module (_api-calls.js)
// Contains functions for interacting with Vercel Functions and WP AJAX.

(function($) { // Use an IIFE
    "use strict";

    // --- API Function URLs ---
    // Vercel URLs (kept for non-auth functions for now)
    const VERCEL_BASE_API_URL = 'https://kairos-wp.vercel.app/api';
    const REFINE_PROMPT_URL = VERCEL_BASE_API_URL + '/refine-prompt';
    const GENERATE_PLUGIN_URL = VERCEL_BASE_API_URL + '/generate-plugin';
    const COMPILE_PLUGIN_URL = VERCEL_BASE_API_URL + '/compile-plugin';
    const REVIEW_PLUGIN_URL = VERCEL_BASE_API_URL + '/review-plugin';
    const REDEEM_COUPON_URL = VERCEL_BASE_API_URL + '/redeem-coupon'; // Nueva URL
    // Vercel Auth URLs (Consolidated)
    const AUTH_ENDPOINT = VERCEL_BASE_API_URL + '/auth'; // CORRECTED: Points to the consolidated auth.ts function
    const REGISTER_URL = VERCEL_BASE_API_URL + '/register';     // Points to Vercel register function (Keep separate for now?)
    // Note: GET_TOKEN_BALANCE_URL is removed as balance is fetched via WP AJAX proxy in _settings-page.js

    // --- WP AJAX Variables (Assumes kairos_wp_object is localized) ---
    const ajaxUrl = (typeof kairos_wp_object !== 'undefined' && kairos_wp_object.ajax_url) ? kairos_wp_object.ajax_url : null;
    const nonce = (typeof kairos_wp_object !== 'undefined' && kairos_wp_object.nonce) ? kairos_wp_object.nonce : null; // Get nonce from localized object

    // --- Authentication Functions ---

    /**
     * Checks token validity with the backend.
     * @returns {Promise<object|null>} - User data object if valid, null otherwise.
     */
    async function verifyToken() {
        const token = localStorage.getItem('kairos_wp_jwt');
        if (!token) return null;

        try {
            // Call the consolidated endpoint with action=me
			const response = await fetch(`${AUTH_ENDPOINT}?action=me`, { // Add action query param for GET
				method: 'GET',
				headers: {
					// 'Content-Type': 'application/json', // Not needed for GET
					'Authorization': `Bearer ${token}`
				}
			});

			if (response.ok) {
				const data = await response.json();
				if (data.success && data.user) {
					return data.user; // Return user data
				} else {
					localStorage.removeItem('kairos_wp_jwt');
					return null;
				}
			} else {
                console.error('[API Calls] Auth check failed:', response.status);
				localStorage.removeItem('kairos_wp_jwt');
				return null;
			}
		} catch (error) {
			console.error('[API Calls] Error calling auth-me function:', error);
			localStorage.removeItem('kairos_wp_jwt');
			return null;
		}
    }

    /**
     * Performs the login API call.
     * @param {string} email - User's email.
     * @param {string} password - User's password.
     * @returns {Promise<object>} - The fetch promise resolving to the API response JSON.
     */
    async function loginApi(email, password) {
        // Call the consolidated endpoint with action=login
        return fetch(AUTH_ENDPOINT, {
            method: 'POST',
            headers: { 'Content-Type': 'application/json' },
            body: JSON.stringify({ action: 'login', email: email, password: password }) // Add action parameter
        })
        .then(response => {
            // Always try to parse JSON, let the caller handle success/error based on data
            return response.json();
        })
        // No catch here, let the caller handle errors
    }

    // --- Agent Interaction Functions (Vercel) ---

    /**
     * Calls the refine-prompt Vercel function.
     * @param {string} token - JWT token.
     * @param {object} payload - Data to send (e.g., { user_prompt: '...' } or { current_prd: '...', improvements: '...' }).
     * @param {string} currentDomain - The current website domain.
     * @returns {Promise<object>} - The response data from the function.
     * @throws {Error} - Throws an error object with status and data on failure.
     */
    async function callRefinePromptApi(token, payload, currentDomain) {
        const fullPayload = { ...payload, current_domain: currentDomain };
        const response = await fetch(REFINE_PROMPT_URL, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify(fullPayload)
        });

        const data = await response.json(); // Try to parse JSON regardless of status

        if (!response.ok) {
            console.error(`[API Calls] Refine Prompt API Error (${response.status}):`, data);
            throw { status: response.status, data: data }; // Throw structured error
        }

        return data; // Return successful data
    }

     /**
     * Calls the generate-plugin Vercel function for a specific code type.
     * @param {string} token - JWT token.
     * @param {string} functionalRequirements - The PRD.
     * @param {string} postTitle - The plugin title.
     * @param {string} currentDomain - The current website domain.
     * @returns {Promise<object>} - The response data containing php_output, js_output, css_output and tokens.
     * @throws {Error} - Throws an error object with status and data on failure.
     */
    async function callGeneratePluginApi(token, functionalRequirements, postTitle, currentDomain) {
        const requestPayload = {
            functional_requirements: functionalRequirements,
            post_title: postTitle,
            current_domain: currentDomain
        };

        const response = await fetch(GENERATE_PLUGIN_URL, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify(requestPayload)
        });

        if (!response.ok) {
            const errorData = await response.json().catch(() => ({ error: 'NETWORK_ERROR', message: `HTTP error! status: ${response.status}` }));
            console.error(`[API Calls] Generate Plugin API Error (${response.status}):`, errorData);
            throw { status: response.status, data: errorData }; 
        }

        const data = await response.json();
        return data; 
    }

    /**
     * Calls the compile-plugin Vercel function.
     * @param {string} token - JWT token.
     * @param {string} phpRaw - Raw PHP code.
     * @param {string} jsRaw - Raw JS code.
     * @param {string} cssRaw - Raw CSS code.
     * @param {string} postTitle - Plugin title.
     * @param {string} functionalRequirements - The PRD.
     * @param {string} currentDomain - The current website domain.
     * @returns {Promise<object>} - The response data containing compiled PHP.
     * @throws {Error} - Throws an error object with status and data on failure.
     */
    async function callCompilePluginApi(token, phpRaw, jsRaw, cssRaw, postTitle, functionalRequirements, currentDomain) {
        const payload = {
            php_raw: phpRaw,
            js_raw: jsRaw,
            css_raw: cssRaw,
            post_title: postTitle,
            functional_requirements: functionalRequirements,
            current_domain: currentDomain
        };
        const response = await fetch(COMPILE_PLUGIN_URL, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify(payload)
        });

        const data = await response.json(); // Try to parse JSON regardless of status

        if (!response.ok) {
            console.error(`[API Calls] Compile Plugin API Error (${response.status}):`, data);
            throw { status: response.status, data: data, codeType: 'compile' }; // Specific error type
        }
        if (!data.success || !data.compiled_php) {
             console.error("[API Calls] Compile plugin response missing data:", data);
             throw new Error(kairos_wp_get_message('error-compile-unexpected-response') || 'Unexpected server response when compiling the plugin.');
        }

        return data;
    }

    /**
     * Calls the review-plugin Vercel function.
     * @param {string} token - JWT token.
     * @param {string} phpCode - Compiled PHP code.
     * @param {string} jsCode - JS code.
     * @param {string} cssCode - CSS code.
     * @param {string} functionalRequirements - The PRD.
     * @param {string} currentDomain - The current website domain.
     * @returns {Promise<object>} - The response data containing review results.
     * @throws {Error} - Throws an error object with status and data on failure.
     */
    async function callReviewPluginApi(token, phpCode, jsCode, cssCode, functionalRequirements, currentDomain) {
        const payload = {
            php_code: phpCode,
            js_code: jsCode,
            css_code: cssCode,
            functional_requirements: functionalRequirements,
            current_domain: currentDomain
        };
        const response = await fetch(REVIEW_PLUGIN_URL, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify(payload)
        });

        const data = await response.json(); // Try to parse JSON regardless of status

        if (!response.ok) {
             console.error(`[API Calls] Review Plugin API Error (${response.status}):`, data);
            throw { status: response.status, data: data };
        }
        if (!data || typeof data.confidence_level === 'undefined') { // Check for expected data
            console.error("[API Calls] Review plugin response missing data:", data);
            throw new Error(kairos_wp_get_message('error-review-unexpected-response') || 'Unexpected server response when reviewing the plugin.');
        }

        return data;
    }


    // --- WordPress AJAX Actions ---

    /**
     * Saves edited content (FR or code) and/or metadata via WP AJAX.
     * @param {number} postId - The WordPress Post ID.
     * @param {string} editType - Type of content being edited ('functional-requirements', 'php', 'js', 'css').
     * @param {string} editedContent - The edited content.
     * @param {object} [metaData={}] - Optional metadata to save (e.g., token counts).
     * @returns {Promise<object>} - The AJAX response object.
     */
    function callWpEditAjax(postId, editType, editedContent, metaData = {}) {
        if (!ajaxUrl || !nonce) {
            console.error("WP AJAX URL or Nonce not available for edit action.");
            return Promise.reject("AJAX configuration missing."); // Return a rejected promise
        }
        return $.ajax({
            url: ajaxUrl,
            type: 'POST',
            data: {
                action: 'edit',
                nonce: nonce,
                edited: editedContent,
                type: editType,
                post_id: postId,
                meta_data: metaData // Pass metadata
            }
        }); // Returns the jQuery AJAX promise
    }

    /**
     * Downloads the generated plugin code as a ZIP file via WP AJAX.
     * @param {number} postId - The WordPress Post ID.
     * @param {string} phpCode - PHP code.
     * @param {string} jsCode - JS code.
     * @param {string} cssCode - CSS code.
     * @returns {Promise<object>} - The AJAX response object.
     */
    function callWpDownloadZipAjax(postId, phpCode, jsCode, cssCode) {
         if (!ajaxUrl || !nonce) {
            console.error("WP AJAX URL or Nonce not available for download action.");
            return Promise.reject("AJAX configuration missing.");
        }
        return $.ajax({
			url: ajaxUrl,
			type: 'POST',
			data: {
				action: 'download_zip',
				nonce: nonce,
				php_code: phpCode,
				js_code: jsCode,
				css_code: cssCode,
				post_id: postId
			}
		});
    }

     /**
     * Saves the generated plugin code to the plugins directory via WP AJAX.
     * @param {number} postId - The WordPress Post ID.
     * @param {string} phpCode - PHP code (decoded).
     * @param {string} jsCode - JS code (decoded).
     * @param {string} cssCode - CSS code (decoded).
     * @returns {Promise<object>} - The AJAX response object.
     */
    function callWpSaveToPluginsAjax(postId, phpCode, jsCode, cssCode) {
         if (!ajaxUrl || !nonce) {
            console.error("WP AJAX URL or Nonce not available for save_to_plugins action.");
            return Promise.reject("AJAX configuration missing.");
        }
        return $.ajax({
            url: ajaxUrl,
            type: 'POST',
            data: {
                action: 'save_to_plugins',
                nonce: nonce,
                php_code: phpCode,
                js_code: jsCode,
                css_code: cssCode,
                post_id: postId
            }
        });
    }

    /**
     * Marks the plugin post as finished (published) via WP AJAX.
     * @param {number} postId - The WordPress Post ID.
     * @returns {Promise<object>} - The AJAX response object.
     */
    function callWpMarkAsFinishedAjax(postId) {
         if (!ajaxUrl || !nonce) {
            console.error("WP AJAX URL or Nonce not available for mark_as_finished action.");
            return Promise.reject("AJAX configuration missing.");
        }
        return $.ajax({
            url: ajaxUrl,
            type: 'POST',
            data: {
                action: 'mark_as_finished',
                nonce: nonce,
                post_id: postId
            }
        });
    }


    // --- Expose functions to be used by other modules ---
    // Using a global object might be simpler than true modules for now in WP context
    window.kairosWpApi = {
        verifyToken,
        // fetchTokenBalanceApi removed as it's handled by WP AJAX proxy
        callRefinePromptApi,
        callGeneratePluginApi,
        callCompilePluginApi,
        callReviewPluginApi,
        callWpEditAjax,
        loginApi,
        callWpDownloadZipAjax,
        callWpSaveToPluginsAjax,
        callWpMarkAsFinishedAjax,
        callRedeemCouponApi, // Exponer la nueva función
        // Expose necessary URLs for _auth.js and potentially other modules
        AUTH_ENDPOINT: AUTH_ENDPOINT,       // URL for login, me, forgotPassword actions
        REGISTER_URL: REGISTER_URL,         // Separate URL for registration
        REDEEM_COUPON_URL: REDEEM_COUPON_URL // Exponer la nueva URL si es necesario para otros módulos
        // Expose VERCEL URLs only if needed elsewhere, otherwise keep them internal
        // VERCEL_BASE_API_URL: VERCEL_BASE_API_URL
    };

    /**
     * Calls the redeem-coupon Vercel function.
     * @param {string} token - JWT token.
     * @param {string} couponCode - The coupon code to redeem.
     * @returns {Promise<object>} - The response data from the function.
     * @throws {Error} - Throws an error object with status and data on failure.
     */
    async function callRedeemCouponApi(token, couponCode) {
        console.log('[API Calls] Inside callRedeemCouponApi. Token:', token ? 'Exists' : 'Missing', 'Coupon:', couponCode); // Log al entrar
        if (!REDEEM_COUPON_URL) {
            console.error("[API Calls] REDEEM_COUPON_URL is not defined.");
            throw { status: 500, data: { message: "Client configuration error for redeem coupon URL.", error: "CLIENT_CONFIG_ERROR" } };
        }
        console.log('[API Calls] REDEEM_COUPON_URL:', REDEEM_COUPON_URL); // Log URL

        const fetchOptions = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Authorization': `Bearer ${token}`
            },
            body: JSON.stringify({ coupon_code: couponCode })
        };

        console.log('[API Calls] Fetch options for redeem coupon:', fetchOptions); // Log de opciones de fetch

        try {
            const response = await fetch(REDEEM_COUPON_URL, fetchOptions);
            console.log('[API Calls] Redeem Coupon API raw response status:', response.status); // Log de status de respuesta

            const data = await response.json(); // Intenta parsear JSON siempre
            console.log('[API Calls] Redeem Coupon API parsed response data:', data); // Log de datos parseados

            if (!response.ok) {
                console.error(`[API Calls] Redeem Coupon API Error (${response.status}):`, data);
                throw { status: response.status, data: data || { message: `HTTP error ${response.status}`, error: 'UNKNOWN_API_ERROR' } };
            }
            
            return data; 
        } catch (error) {
            console.error('[API Calls] Fetch or JSON parse error in callRedeemCouponApi:', error);
            // Re-lanzar el error para que el manejador en _settings-page.js lo capture
            throw error; 
        }
    }

})(jQuery); // End IIFE
