// Kairos WP Plugin - Authentication Module (_auth.js)
// Handles login, registration, forgot password, auth state checking, and related UI updates.

(function($) { // Use an IIFE
    "use strict";

    // Assumes kairosWpApi and utility functions (like kairos_wp_get_message) are globally available
    // or loaded as dependencies via wp_enqueue_script.

    // --- Auth State & UI Management ---

	// Function to update the UI based on login state (Primarily for Settings Page)
	function updateAuthUIState(userData = null) {
		const $authContainer = $('#kairos-wp-auth-container'); // Main container for auth elements
        if (!$authContainer.length) return; // Only run if auth container exists

		const $loginSection = $('#kairos-wp-login-form-section');
		const $registerSection = $('#kairos-wp-register-form-section');
        const $forgotSection = $('#kairos-wp-forgot-password-form-section');
		const $userInfoSection = $('#kairos-wp-user-info-section');

		if (userData && userData.id) {
			// User is logged in
			$loginSection.hide();
			$registerSection.hide();
            $forgotSection.hide();
			$userInfoSection.show();
            $(document).trigger('kairos_wp_auth_ui_ready'); // <-- Trigger event AFTER UI is ready
             $('#kairos-wp-logged-in-email').text(userData.email || 'N/A'); // Assumes element exists

 			// REMOVED: Token balance fetching logic is now handled solely by _settings-page.js
            //          listening for the 'kairos_wp_auth_ui_ready' event.
            //          This prevents duplicate calls and potential errors if API functions change.

 		} else {
 			// User is logged out
			$loginSection.show(); // Show login section by default
			$registerSection.hide(); // Hide register section by default
            $forgotSection.hide(); // Ensure forgot password is hidden initially
			$userInfoSection.hide(); // Hide user info section
			localStorage.removeItem('kairos_wp_jwt'); // Ensure token is removed if invalid
		}
	}

    // Function to check token validity and update UI (Used primarily by Settings Page)
	async function checkAuthStateAndMaybeUpdateUI() {
        // Use the consolidated endpoint for 'me' action
        if (!window.kairosWpApi || typeof window.kairosWpApi.AUTH_ENDPOINT === 'undefined') {
            console.error("[Auth Module] Consolidated Auth API Endpoint URL not available for verifyToken.");
            updateAuthUIState(null); // Assume logged out if API URL missing
            return;
        }
        const apiUrl = window.kairosWpApi.AUTH_ENDPOINT;
        const token = localStorage.getItem('kairos_wp_jwt');

        if (!token) {
            updateAuthUIState(null);
            return;
        }

        try {
            const response = await fetch(`${apiUrl}?action=me`, { // Add action=me query param for GET
                method: 'GET',
                headers: { 'Authorization': `Bearer ${token}` }
            });

            if (!response.ok) {
                 // Attempt to parse error JSON, but handle cases where it might not be JSON
                 const errorData = await response.json().catch(() => ({}));
                 const errorMessage = errorData.message || `HTTP error ${response.status}`;
                 const errorCode = errorData.error || 'UNKNOWN_ERROR';
                 console.warn(`[Auth Module] Token verification failed (${response.status}): ${errorMessage} (Code: ${errorCode})`);
                 
                 // Attempt to get a specific message, otherwise use a generic one for token errors
                 let specificMessageKey = `error-${errorCode.toLowerCase().replace(/_/g, '-')}`;
                 let displayMessage = kairos_wp_get_message(specificMessageKey);

                 if (!displayMessage) { // Fallback for unmapped or generic token errors
                    if (errorCode === 'TOKEN_EXPIRED') displayMessage = kairos_wp_get_message('error-token-expired');
                    else if (errorCode === 'INVALID_TOKEN' || errorCode === 'INVALID_TOKEN_PAYLOAD') displayMessage = kairos_wp_get_message('error-invalid-token');
                    else if (errorCode === 'USER_NOT_FOUND') displayMessage = kairos_wp_get_message('error-user-not-found');
                    else displayMessage = kairos_wp_get_message('error-session-verification-failed'); // Generic session error
                 }
                 // You might want to display 'displayMessage' to the user in a non-intrusive way if needed,
                 // for now, it primarily ensures updateAuthUIState(null) is called for critical auth errors.
                 console.warn(`[Auth Module] Display message for token error: ${displayMessage}`);

                 updateAuthUIState(null); // Always update to logged out on any verification failure
                 return; // Stop processing on error
            }

            const data = await response.json();
            if (data.success && data.user) {
                updateAuthUIState(data.user); // Update UI with user data
            } else {
                console.warn("[Auth Module] 'me' action response structure invalid or success false.");
                updateAuthUIState(null);
            }
        } catch (error) { // Catches network errors or if response.json() itself fails
            console.error('[Auth Module] Network error or JSON parse error during token verification:', error);
            // Display a generic network/connection error message if appropriate
            // This part might need a UI element if we want to inform the user beyond console.
            updateAuthUIState(null); // Assume logged out on network error
        }
	}


    // --- Auth Forms Logic (Settings Page) ---

    // Prevent Enter key submission in password field
    $('#kairos-wp-login-password').on('keypress', function(e) {
        if (e.which === 13) { e.preventDefault(); $('#kairos-wp-login-button').trigger('click'); return false; }
    });

    // Ensure DOM is ready before attaching listeners
    $(document).ready(function() {

        // Login Button Click Handler
        $('#kairos-wp-login-button').on('click', function(e) {
            const email = $('#kairos-wp-login-email').val().trim();
            const password = $('#kairos-wp-login-password').val();
            const $messageDiv = $('#kairos-wp-login-message');
            const $spinner = $('#kairos-wp-login-spinner');
            const $button = $(this);

            $messageDiv.removeClass('success error').text('').hide();
            if (!email || !password) { $messageDiv.text(kairos_wp_get_message('error-login-empty-fields') || 'Please enter email and password.').addClass('error').show(); return; }

            $spinner.show(); $button.prop('disabled', true);

            // Use the consolidated auth endpoint
            if (!window.kairosWpApi || typeof window.kairosWpApi.AUTH_ENDPOINT === 'undefined') {
                 console.error("[Auth Module] Consolidated Auth API Endpoint URL not available.");
                 $messageDiv.text(kairos_wp_get_message('error-internal-api-config') || 'Internal error (API Configuration).').addClass('error').show(); $spinner.hide(); $button.prop('disabled', false); return;
            }
            const apiUrl = window.kairosWpApi.AUTH_ENDPOINT;

            fetch(apiUrl, {
                method: 'POST', headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify({ action: 'login', email: email, password: password }) // Add action parameter
            })
            .then(response => {
                if (!response.ok) {
                    return response.json().catch(() => ({})).then(errorData => {
                        const message = errorData?.message || `HTTP error ${response.status}`;
                        const code = errorData?.error || 'UNKNOWN_ERROR';
                        const error = new Error(message); error.code = code; throw error;
                    });
                } return response.json();
            })
            .then(data => {
                if (data.success && data.token) {
                    localStorage.setItem('kairos_wp_jwt', data.token);
                    $messageDiv.text(kairos_wp_get_message('success-login') || 'Login successful.').addClass('success').show();
                    checkAuthStateAndMaybeUpdateUI();
                } else { // Handle specific login errors from backend
                    localStorage.removeItem('kairos_wp_jwt');
                    let errorMessage = data.message || (kairos_wp_get_message('error-login-unknown') || 'Unknown login error.');
                    if (data.error === 'EMAIL_NOT_VERIFIED') errorMessage = kairos_wp_get_message('error-login-email-not-verified') || 'Email not verified. Check your email.';
                    else if (data.error === 'INVALID_CREDENTIALS') errorMessage = kairos_wp_get_message('error-login-invalid-credentials') || 'Invalid email or password.';
                    $messageDiv.text((kairos_wp_get_message('error-prefix') || 'Error: ') + errorMessage).addClass('error').show();
                    console.error("[Auth Module] Login failed:", data.error || errorMessage);
                }
            })
            .catch(error => { // Handles errors from the fetch promise itself (network, or thrown from !response.ok)
                console.error('[Auth Module] Error calling login function:', error);
                let displayMessage;
                const errorCode = error.code || 'UNKNOWN_ERROR'; // error.code is set if we threw it after parsing JSON

                // Try to get a specific message using our convention
                let specificMessageKey = `error-login-${errorCode.toLowerCase().replace(/_/g, '-')}`;
                if (errorCode === 'EMAIL_NOT_VERIFIED') specificMessageKey = 'error-login-email-not-verified';
                else if (errorCode === 'INVALID_CREDENTIALS') specificMessageKey = 'error-login-invalid-credentials';
                // Add more specific mappings if needed, e.g. for MISSING_REQUIRED_FIELDS etc.
                else if (errorCode === 'MISSING_REQUIRED_FIELDS') specificMessageKey = 'error-login-empty-fields';


                displayMessage = kairos_wp_get_message(specificMessageKey);

                if (!displayMessage) { // Fallback if no specific message found for the code
                    displayMessage = error.message || (kairos_wp_get_message('error-login-connection') || 'Connection error during login attempt.');
                }
                
                $messageDiv.text((kairos_wp_get_message('error-prefix') || 'Error: ') + displayMessage).addClass('error').show();
                localStorage.removeItem('kairos_wp_jwt');
            })
            .finally(() => { $spinner.hide(); $button.prop('disabled', false); });
        });

        // Register Form Submission
        $('#kairos-wp-register-form').on('submit', function(e) {
            e.preventDefault();
            const email = $('#kairos-wp-register-email').val().trim();
            const password = $('#kairos-wp-register-password').val();
            const confirmPassword = $('#kairos-wp-register-confirm-password').val();
            const $messageDiv = $('#kairos-wp-register-message');
            const $spinner = $('#kairos-wp-register-spinner');
            const $button = $('#kairos-wp-register-button');
            const couponCode = $('#kairos-wp-register-coupon').val().trim(); // Obtener el código del cupón
            let captchaToken = '';

            $messageDiv.removeClass('success error').text('').hide();
            if (!email || !password || !confirmPassword) { $messageDiv.text(kairos_wp_get_message('error-register-empty-fields') || 'Please complete all fields.').addClass('error').show(); return; }
            if (password !== confirmPassword) { $messageDiv.text(kairos_wp_get_message('error-register-password-mismatch') || 'Passwords do not match.').addClass('error').show(); return; }
            if (password.length < 8) { $messageDiv.text(kairos_wp_get_message('error-register-password-short') || 'Password must be at least 8 characters.').addClass('error').show(); return; }

            try { // Get CAPTCHA token
                if (typeof hcaptcha !== 'undefined' && typeof hcaptcha.getResponse === 'function') { captchaToken = hcaptcha.getResponse(); }
                if (!captchaToken) { $messageDiv.text(kairos_wp_get_message('error-register-captcha-incomplete') || 'Please complete the CAPTCHA.').addClass('error').show(); return; }
            } catch (error) { console.error('[Auth Module] Error getting hCaptcha response:', error); $messageDiv.text(kairos_wp_get_message('error-register-captcha-verification') || 'Error verifying CAPTCHA.').addClass('error').show(); return; }

            $spinner.show(); $button.prop('disabled', true);

            // Use the consolidated auth endpoint
            if (!window.kairosWpApi || typeof window.kairosWpApi.AUTH_ENDPOINT === 'undefined') {
                 console.error("[Auth Module] Consolidated Auth API Endpoint URL not available.");
                 $messageDiv.text(kairos_wp_get_message('error-internal-api-config') || 'Internal error (API Configuration).').addClass('error').show(); $spinner.hide(); $button.prop('disabled', false); return;
            }
            const apiUrl = window.kairosWpApi.AUTH_ENDPOINT;
            const siteUrl = window.location.origin;

            fetch(apiUrl, {
                method: 'POST', headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify({ 
                    action: 'register', 
                    email: email, 
                    password: password, 
                    siteUrl: siteUrl, 
                    captchaToken: captchaToken,
                    coupon_code: couponCode // Enviar el código del cupón
                })
            })
            .then(response => {
                if (!response.ok) {
                    // Si no está OK, intenta parsear el JSON del error.
                    // Este JSON contendrá nuestro 'error.code' personalizado.
                    return response.json().catch(() => ({
                        // Si el parseo del JSON del error falla, devuelve un objeto
                        // que indique un error de parseo o un error genérico.
                        _isParsedError: true, // Bandera para identificar que esto vino de un !response.ok
                        _parseFailed: true,
                        status: response.status, // Guardar el status original
                        message: `HTTP error ${response.status} (Failed to parse error body)`
                    })).then(errorDataFromServer => {
                        // Añadimos la bandera _isParsedError para que el siguiente .then sepa que esto es un error procesado.
                        // Y también el status original.
                        return { ...errorDataFromServer, _isParsedError: true, status: response.status };
                    });
                }
                return response.json(); // Para respuestas ok (2xx), parsea el JSON de éxito
            })
            .then(data => {
                // Ahora 'data' puede ser el JSON de éxito, o el JSON de error procesado del .then anterior.
                if (data.success && !data._isParsedError) { // Si es éxito Y NO es un error que procesamos antes
                    // --- MODIFICACIÓN INICIO: Mejorar Feedback Post-Registro ---
                    const userEmail = email; // email variable is in scope here
                    let rawSuccessMessage = kairos_wp_get_message('success-register') || 'Registration almost complete! We have sent a verification email to %s. Please click the link in the email to activate your account and then you can log in. If you don\'t see it, please check your spam folder.';
                    const successMessage = rawSuccessMessage.replace('%s', userEmail);
                                        
                    $('#kairos-wp-register-form').hide(); // Ocultar el formulario de registro
                    const $authMessagesContainer = $('#kairos-wp-auth-messages'); 
                    if ($authMessagesContainer.length) {
                        $authMessagesContainer.html(`<div class="notice notice-success is-dismissible"><p>${successMessage}</p></div>`).show();
                    } else {
                        $messageDiv.text(successMessage).removeClass('error').addClass('success').show();
                    }
                    if (typeof hcaptcha !== 'undefined') hcaptcha.reset();
                    // --- MODIFICACIÓN FIN ---
                } else {
                    // Esto se ejecuta si data.success es false, O si data._isParsedError es true.
                    // 'data' aquí es el errorDataFromServer del .then() anterior si !response.ok.
                    const errorCode = data.error || (data._parseFailed ? 'PARSE_FAILED' : 'UNKNOWN_ERROR'); // data.error es nuestro código personalizado
                    let errorMessage;

                    if (errorCode === 'EMAIL_ALREADY_EXISTS') {
                        errorMessage = kairos_wp_get_message('error-register-email-exists') || 'This email is already registered. Try logging in.';
                    } else if (errorCode === 'DOMAIN_ALREADY_REGISTERED_BY_ANOTHER_ACCOUNT') { // Nuevo error específico
                        errorMessage = kairos_wp_get_message('error-domain-already-registered-by-other') || 'This website domain is already registered by another account.';
                    } else if (errorCode === 'DOMAIN_ALREADY_REGISTERED') { // Fallback para el error anterior si aún se usa
                        errorMessage = kairos_wp_get_message('error-register-domain-exists') || 'This website domain has already been registered with an account.';
                    } else if (errorCode === 'CAPTCHA_VERIFICATION_FAILED') {
                        errorMessage = kairos_wp_get_message('error-register-captcha-failed') || 'CAPTCHA verification failed. Try again.';
                    } else if (errorCode === 'PARSE_FAILED') {
                        errorMessage = data.message; // Usar el mensaje que construimos: "HTTP error XXX (Failed to parse error body)"
                    }
                    else {
                        // Intentar mapear otros códigos de error genéricos que podríamos haber añadido
                        let specificMessageKey = `error-${errorCode.toLowerCase().replace(/_/g, '-')}`;
                        errorMessage = kairos_wp_get_message(specificMessageKey);
                        if (!errorMessage) { // Si no hay mapeo para el errorCode
                             // Usar data.message (que podría ser el mensaje del servidor o el que construimos si falló el parseo)
                            errorMessage = data.message || (kairos_wp_get_message('error-register-unknown') || 'Unknown registration error.');
                        }
                    }
                    $messageDiv.text((kairos_wp_get_message('error-prefix') || 'Error: ') + errorMessage).addClass('error').show();
                    if (typeof hcaptcha !== 'undefined') hcaptcha.reset();
                    console.error("[Auth Module] Registration failed (handled in .then):", errorCode, data.message || "No message from server");
                }
            })
            .catch(error => {
                // Este .catch() ahora solo debería manejar errores de red puros (fetch mismo falla)
                // o errores de programación inesperados en los .then().
                console.error('[Auth Module] Network or critical error calling register function (in .catch):', error);
                let displayMessage = error.message || (kairos_wp_get_message('error-register-connection') || 'Connection error during account registration.');
                $messageDiv.text((kairos_wp_get_message('error-prefix') || 'Error: ') + displayMessage).addClass('error').show();
                if (typeof hcaptcha !== 'undefined') hcaptcha.reset();
            })
            .finally(() => { $spinner.hide(); $button.prop('disabled', false); });
        });

        // Forgot Password Form Submission
        $('#kairos-wp-forgot-password-form').on('submit', function(e) {
            e.preventDefault();
            const email = $('#kairos-wp-forgot-email').val().trim();
            const $messageDiv = $('#kairos-wp-forgot-message');
            const $spinner = $('#kairos-wp-forgot-spinner');
            const $button = $('#kairos-wp-forgot-password-button');
            const siteUrl = window.location.origin;

            $messageDiv.removeClass('success error').text('').hide();
            if (!email) { $messageDiv.text(kairos_wp_get_message('error-forgot-password-empty-email') || 'Please enter your email address.').addClass('error').show(); return; }

            $spinner.show(); $button.prop('disabled', true);

            // Use the consolidated auth endpoint
            if (!window.kairosWpApi || typeof window.kairosWpApi.AUTH_ENDPOINT === 'undefined') {
                 console.error("[Auth Module] Consolidated Auth API Endpoint URL not available.");
                 $messageDiv.text(kairos_wp_get_message('error-internal-api-config') || 'Internal error (API Configuration).').addClass('error').show(); $spinner.hide(); $button.prop('disabled', false); return;
            }
            const apiUrl = window.kairosWpApi.AUTH_ENDPOINT;

            fetch(apiUrl, {
                method: 'POST', headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify({ action: 'forgotPassword', email: email, siteUrl: siteUrl }) // Add action
            })
            .then(response => { // Modified to handle potential errors from forgotPassword API
                if (!response.ok) {
                    return response.json().catch(() => ({})).then(errorData => {
                        const message = errorData?.message || `HTTP error ${response.status}`;
                        const code = errorData?.error || 'UNKNOWN_ERROR'; // e.g. MISSING_REQUIRED_FIELDS
                        const error = new Error(message); error.code = code; throw error;
                    });
                }
                return response.json();
            })
            .then(data => { // This .then handles success or parsed error data if response.ok was true but data.success was false
                if (data.success) {
                    $messageDiv.text(kairos_wp_get_message('success-forgot-password-link-sent') || 'If an account exists with that email, a password reset link has been sent.').addClass('success').show();
                    $('#kairos-wp-forgot-password-form')[0].reset();
                } else {
                    // Handle cases where API returns success:false but not a typical HTTP error status
                    let errorMessage = kairos_wp_get_message(`error-forgot-${data.error?.toLowerCase().replace(/_/g, '-')}`) || 
                                       data.message || 
                                       (kairos_wp_get_message('error-general') || 'An unexpected error occurred.');
                    $messageDiv.text((kairos_wp_get_message('error-prefix') || 'Error: ') + errorMessage).addClass('error').show();
                    console.error("[Auth Module] Forgot password failed (API success:false):", data.error || data.message);
                }
            })
            .catch(error => { // This .catch handles network errors or errors thrown from !response.ok
                console.error('[Auth Module] Error calling forgot-password function:', error);
                let displayMessage;
                const errorCode = error.code || 'UNKNOWN_ERROR';

                if (errorCode === 'MISSING_REQUIRED_FIELDS') { // Example specific error code from forgotPassword
                    displayMessage = (kairos_wp_get_message('error-prefix') || 'Error: ') + (kairos_wp_get_message('error-forgot-password-empty-email') || 'Please enter your email address.');
                } else {
                    // For forgot password, it's often better to show a generic success-like message to prevent email enumeration
                    // However, if there's a true connection error, the user should know.
                    // Let's stick to the generic success message for most cases unless it's clearly a client-side or network issue.
                    displayMessage = kairos_wp_get_message('success-forgot-password-link-sent') || 'If an account exists with that email, a password reset link has been sent.';
                    // If error.message suggests a network issue, perhaps show a different message.
                    // For now, keeping it simple and security-conscious.
                }
                $messageDiv.text(displayMessage).addClass(error.code && error.code !== 'UNKNOWN_ERROR' ? 'error' : 'success').show(); // Show as error if we have a specific code
                $('#kairos-wp-forgot-password-form')[0].reset();
            })
            .finally(() => { $spinner.hide(); $button.prop('disabled', false); });
        });

        // Logout Button Click
        $('#kairos-wp-logout-button').on('click', function(e) {
            e.preventDefault();
            localStorage.removeItem('kairos_wp_jwt');
            updateAuthUIState(null);
            $('#kairos-wp-login-message').text(kairos_wp_get_message('success-logout') || 'You have been logged out.').addClass('success').show();
        });

        // Show/Hide Login/Register/Forgot Forms
        const showLoginForm = () => {
            $('#kairos-wp-register-form-section, #kairos-wp-forgot-password-form-section').hide();
            $('#kairos-wp-login-form-section').show();
            $('#kairos-wp-register-message, #kairos-wp-forgot-message').hide();
        };
        const showRegisterForm = () => {
            $('#kairos-wp-login-form-section, #kairos-wp-forgot-password-form-section').hide();
            $('#kairos-wp-register-form-section').show();
            $('#kairos-wp-login-message, #kairos-wp-forgot-message').hide();
        };
         const showForgotForm = () => {
            $('#kairos-wp-login-form-section, #kairos-wp-register-form-section').hide();
            $('#kairos-wp-forgot-password-form-section').show();
            $('#kairos-wp-login-message, #kairos-wp-register-message').hide();
        };

        $('#kairos-wp-show-register-link').on('click', (e) => { e.preventDefault(); showRegisterForm(); });
        $('#kairos-wp-show-login-link').on('click', (e) => { e.preventDefault(); showLoginForm(); });
        $('#kairos-wp-forgot-password-link').on('click', (e) => { e.preventDefault(); showForgotForm(); });
        $('#kairos-wp-cancel-forgot-password-link').on('click', (e) => { e.preventDefault(); showLoginForm(); });

        // Initial Auth Check on Settings Page Load
        const $authContainer = $('#kairos-wp-auth-container');
        if ($authContainer.length > 0) {
            checkAuthStateAndMaybeUpdateUI();
        } else if ($('body').hasClass('settings_page_kairos-wp-settings')) {
            console.warn('[Auth Module] Auth container #kairos-wp-auth-container not found on settings page!');
        }

    }); // End $(document).ready()

})(jQuery); // End IIFE
