// Kairos WP Plugin - CPT Edit Screen Logic (_cpt-screen.js)
// Handles interactions and logic specific to the 'kairos_wp' post type edit screen.

(function($) { // Use an IIFE
    "use strict";

    // Assumes kairosWpApi, utility functions (kairos_wp_get_message, decodeHtmlEntities),
    // and UI helpers (showThickboxLoader, hideThickboxLoader, updateTokenMetaboxDisplay)
    // are globally available or loaded as dependencies via wp_enqueue_script.

    // --- CPT Screen Variables ---
    const postID = $( '#post_ID' ).val();
    const ajaxUrl = (typeof kairos_wp_object !== 'undefined') ? kairos_wp_object.ajax_url : null;
    const nonce = (typeof kairos_wp_object !== 'undefined') ? kairos_wp_object.nonce : null; // Get nonce
    const settingsPage = (typeof kairos_wp_object !== 'undefined') ? kairos_wp_object.link : '#'; // Fallback link
    // Declare variables needed across different parts of the CPT logic here
    const $initialPromptTextarea = $('#kairos-wp-initial-prompt');
    const $sendToLolaButton = $('#kairos-wp-send-to-lola-btn');
    const $improvementsTextarea = $('#kairos-wp-improvements-input');
    const $sendImprovementsButton = $('#kairos-wp-send-improvements-btn');
    const currentDomain = window.location.hostname; // Definir currentDomain


    // --- CPT Screen Specific Functions ---

    // Function to check auth state specifically for CPT screen and update UI elements
	// Returns true if authenticated, false otherwise.
	async function checkAuthStateForCPT() {
        // Ensure API object and verifyToken function exist
        if (!window.kairosWpApi || typeof window.kairosWpApi.verifyToken !== 'function') {
            console.error("[CPT Screen] kairosWpApi.verifyToken not available.");
            $('#kairos-wp-send-to-lola-btn, #kairos-wp-send-to-pablo-btn, #kairos-wp-send-improvements-btn').prop('disabled', true);
            return false;
        }

		const userData = await window.kairosWpApi.verifyToken();
        const isAuthenticated = !!(userData && userData.id);

        // Select buttons (using variables declared above where possible)
		const $pabloButton = $('#kairos-wp-send-to-pablo-btn');

        // Enable/Disable buttons based ONLY on authentication here
        $sendToLolaButton.prop('disabled', !isAuthenticated);
        $pabloButton.prop('disabled', !isAuthenticated);
        $sendImprovementsButton.prop('disabled', !isAuthenticated);

        if (isAuthenticated) {
            const token = localStorage.getItem('kairos_wp_jwt');
            // Check if fetchAndUpdateMetaboxBalance function exists before calling
            if (typeof window.fetchAndUpdateMetaboxBalance === 'function') {
                 window.fetchAndUpdateMetaboxBalance(token);
            } else {
                 console.error("[CPT Screen] fetchAndUpdateMetaboxBalance function not found on window.");
                 // Attempt to call the API directly as a fallback, though UI update won't happen
                 if (window.kairosWpApi && typeof window.kairosWpApi.fetchTokenBalanceApi === 'function') {
                     window.kairosWpApi.fetchTokenBalanceApi(token);
                 }
            }
        }

		return isAuthenticated;
	}

    // --- Event Handlers ---

    // Title enter bug fix
	$( '#title' ).on( 'keypress', function( e ) {
		if ( e.which === 13 ) {
			e.preventDefault();
		}
	});

	// Slug enter bug fix
	$( '#kairos-wp-post-slug' ).on( 'keypress', function( e ) {
		if ( e.which === 13 ) {
			e.preventDefault();
		}
	});

    // Publish button validation
    $( '#publish' ).on( 'click', function(event) {
		if ( $( '#title' ).val() === '' ) {
			$( '#kairos-wp-alert-popup-overlay' ).fadeIn();
			$( '#kairos-wp-alert-text' ).text( kairos_wp_get_message( "error-no-title" ) );
			$( '#kairos-wp-alert-ok' ).data( 'action', 'close' );
			$( '#title' ).focus();
			event.preventDefault();
			return false;
		}
	});

    // Test in Playground button
    $( document ).on( 'click', '.kairos-wp-test-start', function(e) {
        e.preventDefault();

        // --- Restore original code retrieval with added logging ---
        let phpCode = '', jsCode = '', cssCode = '';
        let rawPhpText = '', rawJsText = '', rawCssText = '';

        try {
            rawPhpText = $( '#kairos-wp-hidden-php' ).text();
            phpCode = decodeHtmlEntities(rawPhpText);

            rawJsText = $( '#kairos-wp-hidden-js' ).text();
            jsCode = decodeHtmlEntities(rawJsText); // Get JS code

            rawCssText = $( '#kairos-wp-hidden-css' ).text();
            cssCode = decodeHtmlEntities(rawCssText); // Get CSS code

        } catch (error) {
            console.error("Error during code retrieval or decoding for Playground:", error);
            // Optionally show an alert to the user
            // $( '#kairos-wp-alert-popup-overlay' ).fadeIn();
            // $( '#kairos-wp-alert-text' ).text( 'Error processing code for Playground.' );
            return; // Stop execution if there was an error here
        }
        // --- End code retrieval ---

        if ( !phpCode || !phpCode.trim() ) {
            console.error("Playground: phpCode is empty or whitespace. Stopping blueprint generation.");
            // Ensure kairos_wp_get_message is available or provide fallback text
            // const errorMsg = (typeof kairos_wp_get_message === 'function' ? kairos_wp_get_message( "error-no-code-to-test" ) : null) || 'No code generated yet to test.';
            // $( '#kairos-wp-alert-popup-overlay' ).fadeIn(); // <-- Temporarily disable jQuery popup
            // $( '#kairos-wp-alert-text' ).text( errorMsg ); // <-- Temporarily disable jQuery popup
            return;
        }

        // --- ALIGN BLUEPRINT WITH LEGACY STRUCTURE & KAIROS WP NAMING ---
        // Get the actual plugin slug from a localized variable or a data attribute
        // Assuming kairos_wp_object.plugin_slug is available and contains the CPT's slug
        const actualPluginSlug = (typeof kairos_wp_object !== 'undefined' && kairos_wp_object.plugin_slug) ? kairos_wp_object.plugin_slug : 'kairos-plugin';
        const pluginDirPlayground = `/wordpress/wp-content/plugins/${actualPluginSlug}`;

        const blueprintObject = {
			"preferredVersions": { "php": "latest", "wp": "latest" },
			"landingPage": "/wp-admin/plugins.php",
			"phpExtensionBundles": [ "kitchen-sink" ],
			"features": { "networking": true },
			"steps": [
				{ "step": "login", "username": "admin", "password": "password" },
				{ "step": "defineWpConfigConsts", "consts": { "DB_CHARSET": "utf8mb4", "DB_COLLATE": "utf8mb4_unicode_ci" } },
				{ "step": "mkdir", "path": pluginDirPlayground },
				// PHP File (using plugin-file.php as per Legacy strategy)
				{ "step": "writeFile", "path": `${pluginDirPlayground}/plugin-file.php`, "data": phpCode }
			]
		};

        // JS File (using plugin-scripts.js in root, as per Legacy strategy)
        if (jsCode && jsCode.trim()) {
            blueprintObject.steps.push({
                "step": "writeFile",
                "path": `${pluginDirPlayground}/plugin-scripts.js`,
                "data": jsCode
            });
        }

        // CSS File (using plugin-styles.css in root, as per Legacy strategy)
        if (cssCode && cssCode.trim()) {
             blueprintObject.steps.push({
                "step": "writeFile",
                "path": `${pluginDirPlayground}/plugin-styles.css`,
                "data": cssCode
            });
        }
        
        // Activation Step (using plugin-file.php)
        blueprintObject.steps.push({ 
            "step": "activatePlugin", 
            "pluginPath": `${pluginDirPlayground}/plugin-file.php` 
        });
        // --- END BLUEPRINT LOGIC ---

         // Stringify the entire object once, then encode using btoa
         const blueprintString = JSON.stringify(blueprintObject);
         // Correctly encode Unicode string to Base64
         const bluePrintEncoded = btoa(unescape(encodeURIComponent(blueprintString)));
         const playgroundUrl = `https://playground.wordpress.net/#${bluePrintEncoded}`;
         // Open the Playground URL in a new tab/window
        window.open(playgroundUrl, '_blank');
    });

    // Download ZIP button
	$( document ).on( 'click', '.kairos-wp-download-zip', function(e) {
		e.preventDefault();
		$( '#kairos-wp-loader-overlay' ).fadeIn();

		var phpCode = decodeHtmlEntities($( '#kairos-wp-hidden-php' ).text());
		var jsCode = decodeHtmlEntities($( '#kairos-wp-hidden-js' ).text());
		var cssCode = decodeHtmlEntities($( '#kairos-wp-hidden-css' ).text());

        // Use direct $.ajax as the wrapper might not exist or be correct
        $.ajax({
            url: ajaxUrl,
            type: 'POST',
            data: {
                action: 'kairos_wp_download_zip', // Assuming this action exists and is registered
                nonce: nonce,
                post_id: postID,
                php_code: phpCode,
                js_code: jsCode,
                css_code: cssCode
            },
            success: function(response) {
                if ( response.success ) {
                    window.location.href = response.data; // Trigger download
                } else {
                    $( '#kairos-wp-alert-popup-overlay' ).fadeIn();
                    $( '#kairos-wp-alert-text' ).text( kairos_wp_get_message( response.data ) || 'Error generating ZIP.' );
                }
            },
            error: function() {
                $( '#kairos-wp-alert-popup-overlay' ).fadeIn();
                $( '#kairos-wp-alert-text' ).text( kairos_wp_get_message( 'error-general' ) );
            },
            complete: function() {
                $( '#kairos-wp-loader-overlay' ).fadeOut();
            }
        });
	});

	// Save to plugins button
	$( document ).on( 'click', '#kairos-wp-install-plugin-btn', function(e) {
		e.preventDefault();
		if (!$(this).is(':disabled')) {
			$( '#kairos-wp-loader-overlay' ).fadeIn();

            var phpCodeEncoded = $( '#kairos-wp-hidden-php' ).text();
            var jsCodeEncoded = $( '#kairos-wp-hidden-js' ).text();
            var cssCodeEncoded = $( '#kairos-wp-hidden-css' ).text();
            var phpCode = decodeHtmlEntities(phpCodeEncoded);
            var jsCode = decodeHtmlEntities(jsCodeEncoded);
            var cssCode = decodeHtmlEntities(cssCodeEncoded);

            // Use direct $.ajax
            $.ajax({
                url: ajaxUrl,
                type: 'POST',
                data: {
                    action: 'kairos_wp_save_to_plugins', // Use correct action name
                    nonce: nonce,
                    post_id: postID,
                    php_code: phpCode,
                    js_code: jsCode,
                    css_code: cssCode
                },
                success: function(response) {
                    var messageCode = 'error-general';
                    if ( response.success ) {
                        messageCode = response.data || 'success-save';
                    } else {
                        // Handle potential object response for PHP errors
                        if (typeof response.data === 'object' && response.data !== null && response.data.code) {
                             messageCode = response.data.code;
                             let specificError = `\nError: ${response.data.error}\nLine: ${response.data.line}`;
                             $( '#kairos-wp-alert-text' ).text( kairos_wp_get_message( messageCode ) + specificError );
                             return; // Exit early to show specific error
                        } else {
                            messageCode = response.data || 'error-general';
                        }
                    }
                    $( '#kairos-wp-alert-popup-overlay' ).fadeIn();
                    $( '#kairos-wp-alert-text' ).text( kairos_wp_get_message( messageCode ) );
                },
                error: function() {
                    $( '#kairos-wp-alert-popup-overlay' ).fadeIn();
                    $( '#kairos-wp-alert-text' ).text( kairos_wp_get_message( 'error-general' ) );
                },
                complete: function() {
                    $( '#kairos-wp-loader-overlay' ).fadeOut();
                }
            });
		}
	});

	// Enable/disable Install button based on checkbox
	$( document ).on( 'change', '#kairos-wp-confirm-tested', function() {
		$( '#kairos-wp-install-plugin-btn' ).prop('disabled', !$(this).is(':checked'));
	});


	// Apply improvements button
	$( document ).on( 'click', '#kairos-wp-apply-suggestions-btn', function(e) {
		e.preventDefault();
		var selectedSuggestionsText = '';
		$( '.kairos-wp-alex .kairos-wp-suggestion-checkbox:checked' ).each( function() {
			selectedSuggestionsText += $( this ).val() + '\n';
		});

		if ( selectedSuggestionsText ) {
			var currentImprovements = $improvementsTextarea.val(); // Use variable declared above
			$improvementsTextarea.val(
				currentImprovements.trim() ? currentImprovements.trim() + '\n' + selectedSuggestionsText.trim() : selectedSuggestionsText.trim()
			).focus().trigger('input');
			$( '.kairos-wp-alex .kairos-wp-suggestion-checkbox:checked' ).prop('checked', false);
		} else {
			$( '#kairos-wp-alert-popup-overlay' ).fadeIn();
			$( '#kairos-wp-alert-text' ).text( kairos_wp_get_message( "error-no-suggestions-selected" ) || 'Please select at least one suggestion to apply.' );
		}
	});

	// Edit Requirements Manually button
	$( document ).on( 'click', '#kairos-wp-edit-requirements-btn', function(e) {
		e.preventDefault();
		var currentRequirements = $('#kairos-wp-hidden-requirements').text().trim(); // Get from hidden field
		$( '#kairos-wp-edit-popup-overlay' ).fadeIn();
		$( '#kairos-wp-edit-popup-title' ).text( kairos_wp_get_message("edit-requirements-title") || 'Edit Functional Requirements' );
		$( '#kairos-wp-edit-textarea' ).val( currentRequirements );
		$( '#kairos-wp-edit-submit' ).data( 'type', 'functional-requirements' ); // Keep type for PHP handler
	});

	// Submit edit button (from popup) - Handles MANUAL edits only now
	$( document ).on( 'click', '#kairos-wp-edit-submit', function(e) {
		e.preventDefault();
		var editType = $(this).data('type'); // Should be 'functional-requirements'
		var editedContent = $( '#kairos-wp-edit-textarea' ).val();

		if ( editType !== 'functional-requirements' ) {
            console.error("Incorrect edit type for manual save:", editType);
            return; // Should not happen if button setup is correct
        }
        if ( !editedContent.trim() ) {
			$( '#kairos-wp-edit-popup-overlay' ).fadeOut();
			$( '#kairos-wp-alert-popup-overlay' ).fadeIn();
			$( '#kairos-wp-alert-text' ).text( kairos_wp_get_message( "error-empty-edit" ) );
			return;
		}

		$( '#kairos-wp-edit-popup-overlay' ).fadeOut();
		$( '#kairos-wp-loader-overlay' ).fadeIn();

        // Use direct $.ajax with the specific action
        $.ajax({
            url: ajaxUrl,
            type: 'POST',
            data: {
                action: 'kairos_wp_save_manual_edit', // Use the specific action
                nonce: nonce,
                post_id: postID,
                type: editType, // Still send type for PHP validation
                edited: editedContent
            },
            success: function(response) {
                if (response.success) {
                    // Update UI directly
                    $('#kairos-wp-hidden-requirements').text(editedContent);
                    // Update visible display if it exists on the current screen
                    $('.kairos-wp-requirements-display').html(editedContent.replace(/\n/g, '<br>'));
                    if (typeof window.updateTokenMetaboxDisplay === 'function') {
                        window.updateTokenMetaboxDisplay(response.data?.updated_token_metas || {});
                    }
                    if (typeof wp !== 'undefined' && wp.autosave && typeof wp.autosave.getCompareString === 'function') {
                        wp.autosave.serverLastSave = wp.autosave.getCompareString();
                    }
                    // Re-enable Pablo button as requirements changed
                    $('#kairos-wp-send-to-pablo-btn').prop('disabled', false);
                     // Clear code/review UI elements as they are now invalid
                    $('#kairos-wp-hidden-php, #kairos-wp-hidden-js, #kairos-wp-hidden-css').text('');
                    $('.kairos-wp-view-code-btn').hide();
                    $('#kairos-wp-delivery-screen .kairos-wp-alex').find('#kairos-wp-alex-review-content, #kairos-wp-alex-review-intro').hide();
                    $('#kairos-wp-delivery-screen .kairos-wp-alex').find('#kairos-wp-alex-pending-review').text(kairos_wp_get_message('cpt-text-req-changed') || 'Requirements changed. Please generate code again.').show();

                } else {
                    console.error("Failed to save manual requirements edit:", response.data?.message || response.data);
                    $('#kairos-wp-alert-popup-overlay').fadeIn();
                    $('#kairos-wp-alert-text').text(response.data?.message || kairos_wp_get_message('error-general'));
                }
            },
            error: function() {
                $('#kairos-wp-alert-popup-overlay').fadeIn();
                $('#kairos-wp-alert-text').text(kairos_wp_get_message('error-general'));
            },
            complete: function() {
                $('#kairos-wp-loader-overlay').fadeOut();
            }
        });
	});

	// Rephrase user prompt (Initial idea - Lola Button)
	$( document ).on( 'click', '#kairos-wp-send-to-lola-btn', async function(e) {
		console.log('LOLA BTN CLICKED - Initial Idea Send'); // <-- LOG AÑADIDO
		e.preventDefault();
		var initialPrompt = $initialPromptTextarea.val().trim();
		const $button = $(this);
		// const $spinner = $('#kairos-wp-lola-thinking'); // Ya no se usa el spinner

		// console.log('Attempting to show Lola spinner (Initial Idea). Element found:', $spinner.length, 'Spinner var:', $spinner); // Log ya no necesario
		if ( !initialPrompt ) { /* ... validation ... */ return; }
		const token = localStorage.getItem('kairos_wp_jwt');
		if (!token) { /* ... validation ... */ return; }

		// $spinner.show(); // Reemplazado por ThickBox
		$button.prop('disabled', true);

        if (!window.kairosWpApi || typeof window.kairosWpApi.callRefinePromptApi !== 'function') { /* ... handle missing API ... */ return; }

		try {
            if (typeof window.showThickboxLoader === 'function') window.showThickboxLoader('Lola', 'lola-processing-initial-idea');
            const payload = { user_prompt: initialPrompt };
            const data = await window.kairosWpApi.callRefinePromptApi(token, payload, currentDomain); // Pasar currentDomain

			if (data && data.refined_requirements) {
				var refinedRequirements = data.refined_requirements;
				const lolaTokens = data.lola_tokens?.total_tokens || 0;

                // Use direct $.ajax with the specific action
                await $.ajax({
                    url: ajaxUrl,
                    type: 'POST',
                    data: {
                        action: 'kairos_wp_save_initial_lola', // Use specific action
                        nonce: nonce,
                        post_id: postID,
                        functional_requirements: refinedRequirements,
                        lola_initial_tokens: lolaTokens
                    }
                }).then(function(saveResponse) {
                    if (!saveResponse.success) {
                        console.warn("Failed to save initial Lola results:", saveResponse.data?.message || saveResponse.data);
                        throw new Error(saveResponse.data?.message || "Failed to save initial requirements.");
                    } else {
                        // Update UI AFTER successful save
                        $('#kairos-wp-initial-lola-screen').hide();
                        $('#kairos-wp-refined-lola-screen .kairos-wp-requirements-display').html(refinedRequirements.replace(/\n/g, '<br>'));
                        $('#kairos-wp-hidden-requirements').text(refinedRequirements);
                        $('#kairos-wp-refined-lola-screen').show();
                        if (typeof window.updateTokenMetaboxDisplay === 'function') {
                            window.updateTokenMetaboxDisplay(saveResponse.data?.updated_token_metas || {});
                        }
                        if (window.kairosWpApi?.fetchAndUpdateMetaboxBalance) {
                            window.kairosWpApi.fetchAndUpdateMetaboxBalance(token);
                        }
                        if (typeof wp !== 'undefined' && wp.autosave && typeof wp.autosave.getCompareString === 'function') {
                            wp.autosave.serverLastSave = wp.autosave.getCompareString();
                        }
                    }
                }).catch(function(jqXHR, textStatus, errorThrown) {
                    console.error("AJAX error saving initial Lola results:", textStatus, errorThrown);
                    throw new Error("AJAX error saving initial requirements."); // Re-throw
                });

			} else {
				console.error("Refine prompt response missing data:", data);
				throw new Error(kairos_wp_get_message('error-lola-unexpected-response') || 'Unexpected server response.');
			}

        } catch (error) {
            console.error('Error calling api-refine-prompt (initial) or saving results:', error);
			let errorMessage = kairos_wp_get_message('error-api-generic'); // Default generic
            if (error?.status === 401 || error?.status === 403) {
                errorMessage = kairos_wp_get_message('error-auth-failed');
            } else if (error?.status === 402 || error?.code === 'QUOTA_EXCEEDED' || (error?.data?.error === 'QUOTA_EXCEEDED')) {
                errorMessage = kairos_wp_get_message('error-quota-exceeded');
            } else if (error?.data?.error === 'DOMAIN_REGISTERED_TO_ANOTHER_ACCOUNT') {
                errorMessage = kairos_wp_get_message('error-domain-already-registered-by-other') || 'This website domain is already registered to another Kairos WP account.';
            } else if (error?.data?.error === 'DOMAIN_ASSOCIATION_FAILED') {
                errorMessage = kairos_wp_get_message('error-domain-association-failed') || 'Could not associate this website domain with your account.';
            } else if (error?.data?.error === 'MISSING_CURRENT_DOMAIN') {
                errorMessage = kairos_wp_get_message('error-missing-current-domain') || 'Critical error: Current domain was not sent to the server.';
            } else if (error?.status === 504 || (error?.data?.message && error.data.message.toLowerCase().includes('timeout'))) {
                errorMessage = kairos_wp_get_message('error-api-timeout');
            } else if (error?.message && (error.message.toLowerCase().includes('networkerror') || error.message.toLowerCase().includes('failed to fetch'))) {
                errorMessage = kairos_wp_get_message('error-network');
            } else if (error?.data?.error) {
                 errorMessage = `${kairos_wp_get_message('error-api-generic')} (Detalle: ${error.data.error})`; // Append specific detail if available
            } else if (error?.message) {
                 errorMessage = `${kairos_wp_get_message('error-api-generic')} (Detalle: ${error.message})`;
            }
			$( '#kairos-wp-alert-popup-overlay' ).fadeIn();
			$( '#kairos-wp-alert-text' ).text(errorMessage);
        } finally {
            // $spinner.hide(); // Reemplazado por ThickBox
            if (typeof window.hideThickboxLoader === 'function') window.hideThickboxLoader();
            const isAuthenticated = await checkAuthStateForCPT();
            const hasText = $initialPromptTextarea.val().trim().length > 0;
            $button.prop('disabled', !(isAuthenticated && hasText));
        }
	});

    // Handle "Send Requirements to Pablo" button click
	$( document ).on( 'click', '#kairos-wp-send-to-pablo-btn', async function(e) {
		e.preventDefault();
		const $button = $(this);
		const functionalRequirements = $('#kairos-wp-hidden-requirements').text().trim();
		const postTitle = $('#title').val().trim();

		let accumulatedPhp = '', accumulatedJs = '', accumulatedCss = '', accumulatedPabloTokens = 0;

		if (!functionalRequirements) { 
            alert(kairos_wp_get_message('error-empty-requirements') || 'Functional requirements cannot be empty.');
            return; 
        }
		if (!postTitle) { 
            alert(kairos_wp_get_message('error-no-title') || 'Please enter a title for your plugin.');
            return; 
        }
		const token = localStorage.getItem('kairos_wp_jwt');
		if (!token) { 
            alert(kairos_wp_get_message('error-auth-failed') || 'Authentication failed. Please log in.'); // Or redirect
            return; 
        }

        // Ensure API functions are available
        if (!window.kairosWpApi || typeof window.kairosWpApi.callGeneratePluginApi !== 'function' || typeof window.kairosWpApi.callCompilePluginApi !== 'function') {
             console.error("[CPT Screen] Required API functions (callGeneratePluginApi or callCompilePluginApi) not available.");
             alert(kairos_wp_get_message('error-api-functions-not-loaded') || "Error: API functions not loaded correctly.");
             return;
        }

		showThickboxLoader('Pablo', 'pablo-generating-php');
		$button.prop('disabled', true);
		$sendImprovementsButton.prop('disabled', true);

		try {
            // Step 1: Publish the CPT via AJAX (sin cambios aquí)
            if (typeof window.showThickboxLoader === 'function') window.showThickboxLoader('System', 'system-publishing-data');
            await $.ajax({
                url: ajaxUrl,
                type: 'POST',
                data: {
                    action: 'kairos_wp_publish_cpt_before_pablo',
                    nonce: nonce,
                    post_id: postID
                }
            }).then(function(publishResponse) {
                if (!publishResponse.success) {
                    console.error("Failed to publish CPT before sending to Pablo:", publishResponse.data?.message || publishResponse.data);
                    throw new Error(publishResponse.data?.message || "Failed to publish CPT.");
                }
                console.log("CPT Published (or already published) successfully before Pablo call.");
            }).catch(function(jqXHR, textStatus, errorThrown) {
                console.error("AJAX error publishing CPT:", textStatus, errorThrown);
                throw new Error("AJAX error publishing CPT before generation.");
            });

            // Step 2: Call Pablo (Vercel Function)
            if (typeof window.showThickboxLoader === 'function') window.showThickboxLoader('Pablo', 'pablo-generating-plugin-friendly');
            const pabloResult = await window.kairosWpApi.callGeneratePluginApi(token, functionalRequirements, postTitle, currentDomain); // Pasar currentDomain
            
            accumulatedPhp = pabloResult.php_output || '';
            accumulatedJs = pabloResult.js_output || '';
            accumulatedCss = pabloResult.css_output || '';
            // The Vercel function now returns pablo_tokens which is an object {prompt_tokens, completion_tokens, total_tokens}
            // or a default {0,0,0} if not present. We need the total_tokens from that.
            accumulatedPabloTokens = pabloResult.pablo_tokens?.total_tokens || 0; 

            if (!accumulatedPhp.trim()) console.warn("PHP code received from API is empty.");
            // JS and CSS can be empty, so no warning for them if they are.

            // --- Compile Step (Uses Vercel) ---
            showThickboxLoader('Pablo', kairos_wp_get_message('pablo-compiling') || 'Pablo is compiling the plugin...');
            const compileData = await window.kairosWpApi.callCompilePluginApi(token, accumulatedPhp, accumulatedJs, accumulatedCss, postTitle, functionalRequirements, currentDomain); // Pasar currentDomain
            const compiledPhp = compileData.compiled_php;
            // --- End Compile Step ---

            // --- Save Pablo's results via WP AJAX ---
            const pabloSaveData = {
                action: 'kairos_wp_save_pablo_results', // Use specific action
                nonce: nonce,
                post_id: postID,
                php_output: compiledPhp, // Send compiled PHP
                js_output: accumulatedJs,
                css_output: accumulatedCss,
                pablo_tokens: accumulatedPabloTokens // Send accumulated tokens
            };

            await $.ajax({
                url: ajaxUrl,
                type: 'POST',
                data: pabloSaveData
            }).then(function(saveResponse) {
                if (!saveResponse.success) {
                    console.warn("Failed to save Pablo's results:", saveResponse.data?.message || saveResponse.data);
                    throw new Error(saveResponse.data?.message || "Failed to save Pablo's results.");
                } else {
                    // Update UI AFTER successful save
                    $('#kairos-wp-refined-lola-screen').hide();
                    $('#kairos-wp-hidden-php').text(compiledPhp);
                    $('#kairos-wp-hidden-js').text(accumulatedJs);
                    $('#kairos-wp-hidden-css').text(accumulatedCss);
                    $('#kairos-wp-delivery-screen #kairos-wp-hidden-requirements').text(functionalRequirements);
                    const $alexCard = $('#kairos-wp-delivery-screen .kairos-wp-alex');
                    // Reset Alex card UI before triggering review
                    if ($alexCard.length) {
                         $alexCard.find('#kairos-wp-alex-review-content').hide();
                         $alexCard.find('#kairos-wp-alex-review-intro').hide();
                         $alexCard.find('#kairos-wp-alex-pending-review').text(kairos_wp_get_message('alex-reviewing') || 'Now it\'s my turn! I\'m reviewing Pablo\'s code...').show();
                         $alexCard.find('#kairos-wp-confidence-level').removeClass('confidence-level-low confidence-level-medium confidence-level-high').data('confidence-level', '');
                         $alexCard.find('#kairos-wp-confidence-level h5').first().html(`${kairos_wp_get_message('Confidence Level:') || 'Confidence Level:'} ${kairos_wp_get_message('N/A') || 'N/A'}`);
                         $alexCard.find('#kairos-wp-confidence-explanation-text').text(kairos_wp_get_message('Review pending or explanation not available.') || 'Review pending or explanation not available.');
                         $alexCard.find('.kairos-wp-suggestions-checkbox-list').empty().hide();
                         $alexCard.find('.kairos-wp-no-suggestions').show();
                         $alexCard.find('#kairos-wp-apply-suggestions-btn').hide();
                    }
                    $('#kairos-wp-delivery-screen').show();
                    // Cambiar .toggle() por .show()/.hide() ya que los botones ahora siempre existen en el DOM
                    if (accumulatedJs && accumulatedJs.trim()) {
                        $('#kairos-wp-delivery-screen .kairos-wp-view-code-btn[data-type="js"]').show();
                    } else {
                        $('#kairos-wp-delivery-screen .kairos-wp-view-code-btn[data-type="js"]').hide();
                    }
                    if (accumulatedCss && accumulatedCss.trim()) {
                        $('#kairos-wp-delivery-screen .kairos-wp-view-code-btn[data-type="css"]').show();
                    } else {
                        $('#kairos-wp-delivery-screen .kairos-wp-view-code-btn[data-type="css"]').hide();
                    }
                    $('#kairos-wp-confirm-tested').prop('checked', false);
                    $('#kairos-wp-install-plugin-btn').prop('disabled', true);

                    // Update token display
                    if (typeof window.updateTokenMetaboxDisplay === 'function') {
                        window.updateTokenMetaboxDisplay(saveResponse.data?.updated_token_metas || {});
                    }
                    if (window.kairosWpApi?.fetchAndUpdateMetaboxBalance) {
                        window.kairosWpApi.fetchAndUpdateMetaboxBalance(token);
                    }
                    if (typeof wp !== 'undefined' && wp.autosave && typeof wp.autosave.getCompareString === 'function') {
                        wp.autosave.serverLastSave = wp.autosave.getCompareString();
                    }
                    // THEN trigger Alex review (passing compiled PHP)
                    triggerAlexReview(token, compiledPhp, accumulatedJs, accumulatedCss, functionalRequirements, $alexCard, accumulatedPabloTokens, currentDomain); // Pasar currentDomain
                }
            }).catch(function(jqXHR, textStatus, errorThrown) {
                 console.error("AJAX error saving Pablo's results:", textStatus, errorThrown);
                 throw new Error("AJAX error saving Pablo's results."); // Re-throw
            });
            // --- End Save Pablo's results ---

		} catch (error) { 
			console.error("Error during Pablo generation or subsequent steps:", error);
			hideThickboxLoader();
            let errorMessage = kairos_wp_get_message('error-api-generic'); // Default generic
            if (error?.status === 401 || error?.status === 403) {
                errorMessage = kairos_wp_get_message('error-auth-failed');
            } else if (error?.status === 402 || error?.code === 'QUOTA_EXCEEDED' || (error?.data?.error === 'QUOTA_EXCEEDED')) {
                errorMessage = kairos_wp_get_message('error-quota-exceeded');
            } else if (error?.data?.error === 'DOMAIN_REGISTERED_TO_ANOTHER_ACCOUNT') {
                errorMessage = kairos_wp_get_message('error-domain-already-registered-by-other') || 'This website domain is already registered to another Kairos WP account.';
            } else if (error?.data?.error === 'DOMAIN_ASSOCIATION_FAILED') {
                errorMessage = kairos_wp_get_message('error-domain-association-failed') || 'Could not associate this website domain with your account.';
            } else if (error?.data?.error === 'MISSING_CURRENT_DOMAIN') {
                errorMessage = kairos_wp_get_message('error-missing-current-domain') || 'Critical error: Current domain was not sent to the server.';
            } else if (error?.status === 504 || (error?.data?.message && error.data.message.toLowerCase().includes('timeout')) || (error?.message && error.message.toLowerCase().includes('timeout'))) {
                errorMessage = kairos_wp_get_message('error-api-timeout');
            } else if (error?.message && (error.message.toLowerCase().includes('networkerror') || error.message.toLowerCase().includes('failed to fetch'))) {
                errorMessage = kairos_wp_get_message('error-network');
            } else if (error?.codeType === 'compile') {
                errorMessage = `${kairos_wp_get_message('error-api-generic')} (Fase: Compilación. Detalle: ${error?.data?.message || 'Error desconocido.'})`;
            } else if (error?.data?.error) {
                 errorMessage = `${kairos_wp_get_message('error-api-generic')} (API: ${error?.codeType || 'Desconocida'}. Detalle: ${error.data.error})`;
            } else if (error?.message) {
                 errorMessage = `${kairos_wp_get_message('error-api-generic')} (Detalle: ${error.message})`;
            }
			$('#kairos-wp-alert-popup-overlay').fadeIn();
			$('#kairos-wp-alert-text').text(errorMessage);
			$button.prop('disabled', false); // Re-enable buttons on error
			$sendImprovementsButton.prop('disabled', false);
		}
	});

    // --- Function to Trigger Alex Review ---
    async function triggerAlexReview(token, phpCode, jsCode, cssCode, functionalRequirements, $alexCard, accumulatedPabloTokens, currentDomain) { // Added currentDomain
        showThickboxLoader('Alex', 'alex-reviewing');

        if (!window.kairosWpApi || typeof window.kairosWpApi.callReviewPluginApi !== 'function') { /* ... handle missing API ... */ return; }

        try {
            const reviewData = await window.kairosWpApi.callReviewPluginApi(token, phpCode, jsCode, cssCode, functionalRequirements, currentDomain); // Pasar currentDomain

            // Prepare data for saving Alex's review
            const alexTokens = reviewData.alex_tokens?.total_tokens || 0;
            const alexSaveData = {
                action: 'kairos_wp_save_alex_review', // Use specific action
                nonce: nonce,
                post_id: postID,
                confidence_level: reviewData.confidence_level,
                explanation: reviewData.confidence_level_explanation || '',
                suggestions: JSON.stringify(reviewData.suggestions || []),
                alex_tokens: alexTokens
                // Note: We don't need to send pablo_tokens here, PHP calculates cumulative
            };

            // Save Alex's review results using direct $.ajax
            await $.ajax({
                url: ajaxUrl,
                type: 'POST',
                data: alexSaveData
            }).then(function(saveAlexResponse) {
                 if (!saveAlexResponse.success) {
                     console.warn("Failed to save Alex review:", saveAlexResponse.data?.message || saveAlexResponse.data);
                     // Show error in Alex card?
                     if ($alexCard?.length) { $alexCard.find('#kairos-wp-alex-pending-review').html(`<span style="color: red;">${kairos_wp_get_message('cpt-error-saving-review') || 'Error saving review.'}</span>`).show(); }
                 } else {
                     // Update UI AFTER successful save
                     if ($alexCard?.length) {
                         let $reviewContentDiv = $('#kairos-wp-alex-review-content');
                         $alexCard.find('#kairos-wp-alex-pending-review').hide();
                         $alexCard.find('#kairos-wp-alex-review-intro').show();
                         const confidenceLevel = reviewData.confidence_level || 'N/A';
                         const explanation = reviewData.confidence_level_explanation || kairos_wp_get_message('No explanation provided.') || 'No explanation provided.';
                         const $confidenceDiv = $reviewContentDiv.find('#kairos-wp-confidence-level');
                         const $explanationP = $reviewContentDiv.find('#kairos-wp-confidence-explanation-text');
                         if (confidenceLevel !== 'N/A') { 
                            let parentConfidenceClass = 'confidence-level-low'; // Default to low for the parent div
                            if (parseFloat(confidenceLevel) >= 75) {
                                parentConfidenceClass = 'confidence-level-high';
                            } else if (parseFloat(confidenceLevel) >= 50) {
                                parentConfidenceClass = 'confidence-level-medium';
                            }
                            
                            // Update parent div's class (still useful for other potential styling, though not primary for h5 color now)
                            $confidenceDiv.removeClass('confidence-level-low confidence-level-medium confidence-level-high').addClass(parentConfidenceClass);
                            // void $confidenceDiv[0].offsetHeight; // Force reflow - can be removed if applying color directly

                            // Update the text and color of the h5 directly
                            const $h5 = $confidenceDiv.find('h5').first();
                            let h5Color = '#444'; // Default color (gray)

                            if (parentConfidenceClass === 'confidence-level-high') {
                                h5Color = '#4CAF50'; // Green
                            } else if (parentConfidenceClass === 'confidence-level-medium') {
                                h5Color = '#FF9800'; // Orange
                            } else if (parentConfidenceClass === 'confidence-level-low') {
                                h5Color = '#F44336'; // Red
                            }
                            
                            $h5.css('color', h5Color);
                            $h5.html(`${kairos_wp_get_message('Confidence Level:') || 'Confidence Level:'} ${confidenceLevel}%`);
                            $confidenceDiv.data('confidence-level', confidenceLevel);

                         } else { /* ... reset confidence UI ... */
                            const $h5 = $confidenceDiv.find('h5').first();
                            $confidenceDiv.removeClass('confidence-level-low confidence-level-medium confidence-level-high');
                            $h5.css('color', ''); // Reset to default CSS color
                            $h5.html(`${kairos_wp_get_message('Confidence Level:') || 'Confidence Level:'} ${kairos_wp_get_message('N/A') || 'N/A'}`);
                            $confidenceDiv.data('confidence-level', '');
                         }
                         $explanationP.text(explanation);
                         const suggestions = reviewData.suggestions || [];
                         const $suggestionsList = $reviewContentDiv.find('.kairos-wp-suggestions-checkbox-list');
                         const $noSuggestionsP = $reviewContentDiv.find('.kairos-wp-no-suggestions');
                         const $applySuggestionsBtn = $reviewContentDiv.find('#kairos-wp-apply-suggestions-btn');
                         $suggestionsList.empty();
                         if (suggestions.length > 0) { /* ... update suggestions UI ... */
                            suggestions.forEach(suggestion => {
                                const $li = $('<li></li>');
                                const $label = $('<label class="kairos-wp-checkbox-label"></label>');
                                const $checkbox = $('<input type="checkbox" class="kairos-wp-suggestion-checkbox">').val(suggestion);
                                $label.append($checkbox).append($('<span></span>').text(` ${suggestion}`));
                                $li.append($label);
                                $suggestionsList.append($li);
                            });
                            $suggestionsList.show();
                            $noSuggestionsP.hide();
                            $applySuggestionsBtn.show();
                         } else { /* ... reset suggestions UI ... */
                            $suggestionsList.hide();
                            $noSuggestionsP.show();
                            $applySuggestionsBtn.hide();
                         }
                         $reviewContentDiv.show();
                     }
                     // Update token display
                     if (typeof window.updateTokenMetaboxDisplay === 'function') {
                         window.updateTokenMetaboxDisplay(saveAlexResponse.data?.updated_token_metas || {});
                     }
                     if (window.kairosWpApi?.fetchAndUpdateMetaboxBalance) {
                         window.kairosWpApi.fetchAndUpdateMetaboxBalance(token);
                     }
                     if (typeof wp !== 'undefined' && wp.autosave && typeof wp.autosave.getCompareString === 'function') {
                        wp.autosave.serverLastSave = wp.autosave.getCompareString();
                     }
                 }
            }).catch(function(jqXHR, textStatus, errorThrown) {
                console.error("AJAX error saving Alex review:", textStatus, errorThrown);
                if ($alexCard?.length) { $alexCard.find('#kairos-wp-alex-pending-review').html(`<span style="color: red;">${kairos_wp_get_message('cpt-error-ajax-saving-review') || 'AJAX error saving review.'}</span>`).show(); }
            });

        } catch (reviewError) { 
            console.error('Error calling api-review-plugin:', reviewError);
            let reviewErrorMessage = kairos_wp_get_message('error-api-generic'); // Default generic
            if (reviewError?.status === 401 || reviewError?.status === 403) {
                reviewErrorMessage = kairos_wp_get_message('error-auth-failed');
            } else if (reviewError?.status === 402 || reviewError?.code === 'QUOTA_EXCEEDED' || (reviewError?.data?.error === 'QUOTA_EXCEEDED')) {
                reviewErrorMessage = kairos_wp_get_message('error-quota-exceeded');
            } else if (reviewError?.data?.error === 'DOMAIN_REGISTERED_TO_ANOTHER_ACCOUNT') {
                reviewErrorMessage = kairos_wp_get_message('error-domain-already-registered-by-other') || 'This website domain is already registered to another Kairos WP account.';
            } else if (reviewError?.data?.error === 'DOMAIN_ASSOCIATION_FAILED') {
                reviewErrorMessage = kairos_wp_get_message('error-domain-association-failed') || 'Could not associate this website domain with your account.';
            } else if (reviewError?.data?.error === 'MISSING_CURRENT_DOMAIN') {
                reviewErrorMessage = kairos_wp_get_message('error-missing-current-domain') || 'Critical error: Current domain was not sent to the server.';
            } else if (reviewError?.status === 504 || (reviewError?.data?.message && reviewError.data.message.toLowerCase().includes('timeout'))) {
                reviewErrorMessage = kairos_wp_get_message('error-api-timeout');
            } else if (reviewError?.message && (reviewError.message.toLowerCase().includes('networkerror') || reviewError.message.toLowerCase().includes('failed to fetch'))) {
                reviewErrorMessage = kairos_wp_get_message('error-network');
            } else if (reviewError?.data?.error) {
                 reviewErrorMessage = `${kairos_wp_get_message('error-api-generic')} (API Review. Detalle: ${reviewError.data.error})`;
            } else if (reviewError?.message) {
                 reviewErrorMessage = `${kairos_wp_get_message('error-api-generic')} (Detalle: ${reviewError.message})`;
            }

            if ($alexCard?.length) { $alexCard.find('#kairos-wp-alex-pending-review').html(`<span style="color: red;">${reviewErrorMessage}</span>`).show(); }
            else { 
                $('#kairos-wp-alert-popup-overlay').fadeIn();
                $('#kairos-wp-alert-text').text(reviewErrorMessage);
            }
        } finally {
            hideThickboxLoader();
        }
    }

	// Handle "Send Improvements to Lola for Refinement" button click
	$( document ).on( 'click', '#kairos-wp-send-improvements-btn', async function(e) {
		console.log('LOLA BTN CLICKED - Send Improvements'); // <-- LOG AÑADIDO
		e.preventDefault();
		const improvementsText = $improvementsTextarea.val().trim();
		const currentRequirements = $( '#kairos-wp-hidden-requirements' ).text().trim();
		const $button = $(this);
		// const $spinner = $('#kairos-wp-lola-thinking'); // Ya no se usa el spinner

		// console.log('Attempting to show Lola spinner (Send Improvements). Element found:', $spinner.length, 'Spinner var:', $spinner); // Log ya no necesario
		if ( !improvementsText ) { /* ... validation ... */ return; }
		if ( !currentRequirements ) { /* ... validation ... */ return; }
		const token = localStorage.getItem('kairos_wp_jwt');
		if (!token) { /* ... validation ... */ return; }
        if (!window.kairosWpApi || typeof window.kairosWpApi.callRefinePromptApi !== 'function') { /* ... handle missing API ... */ return; }

		// $spinner.show(); // Reemplazado por ThickBox
		$button.prop('disabled', true);
        let operationSuccessful = false; // Flag to track success

		try {
            if (typeof window.showThickboxLoader === 'function') window.showThickboxLoader('Lola', 'lola-processing-improvements');
            const payload = { current_prd: currentRequirements, improvements: improvementsText };
            const data = await window.kairosWpApi.callRefinePromptApi(token, payload, currentDomain); // Pasar currentDomain

			if (data && data.refined_requirements) {
				const lolaRefineTokens = data.lola_tokens?.total_tokens || 0;
                const refinedRequirements = data.refined_requirements;

                // Use direct $.ajax with the specific action
                await $.ajax({
                    url: ajaxUrl,
                    type: 'POST',
                    data: {
                        action: 'kairos_wp_save_refined_lola', // Use specific action
                        nonce: nonce,
                        post_id: postID,
                        functional_requirements: refinedRequirements, // Send requirements
                        lola_refine_tokens: lolaRefineTokens // Send tokens
                    }
                }).then(function(saveResponse) {
                     if (!saveResponse.success) {
                         console.warn("Failed to save refined requirements and tokens:", saveResponse.data?.message || saveResponse.data);
                         throw new Error(saveResponse.data?.message || "Failed to save updated requirements.");
                     } else {
                         // --- Explicit UI Update Logic ---
                         $('#kairos-wp-hidden-requirements').text(refinedRequirements);
                         $('#kairos-wp-delivery-screen').hide(); // Explicitly hide delivery
                         $('#kairos-wp-refined-lola-screen .kairos-wp-requirements-display').html(refinedRequirements.replace(/\n/g, '<br>')); // Update visible requirements
                         $('#kairos-wp-refined-lola-screen').show(); // Explicitly show refined screen
                         $('#kairos-wp-send-to-pablo-btn').prop('disabled', false); // Explicitly enable Pablo button
                         $improvementsTextarea.val('');
                         $sendImprovementsButton.prop('disabled', true); // Disable improvements button (textarea is empty)
                         operationSuccessful = true; // Mark success

                         // Update token display
                         if (typeof window.updateTokenMetaboxDisplay === 'function') {
                             window.updateTokenMetaboxDisplay(saveResponse.data?.updated_token_metas || {});
                         }
                         if (window.kairosWpApi?.fetchAndUpdateMetaboxBalance) {
                             window.kairosWpApi.fetchAndUpdateMetaboxBalance(token);
                         }
                         if (typeof wp !== 'undefined' && wp.autosave && typeof wp.autosave.getCompareString === 'function') {
                            wp.autosave.serverLastSave = wp.autosave.getCompareString();
                         }
                     }
                }).catch(function(jqXHR, textStatus, errorThrown) {
                     console.error("AJAX error saving refined requirements:", textStatus, errorThrown);
                     throw new Error("AJAX error saving updated requirements."); // Re-throw
                });

			} else { /* ... handle missing data ... */ throw new Error('Unexpected server response.'); }
        } catch (error) { 
            console.error('Error refining improvements:', error);
            let errorMessage = kairos_wp_get_message('error-api-generic'); // Default generic
            if (error?.status === 401 || error?.status === 403) {
                errorMessage = kairos_wp_get_message('error-auth-failed');
            } else if (error?.status === 402 || error?.code === 'QUOTA_EXCEEDED' || (error?.data?.error === 'QUOTA_EXCEEDED')) {
                errorMessage = kairos_wp_get_message('error-quota-exceeded');
            } else if (error?.data?.error === 'DOMAIN_REGISTERED_TO_ANOTHER_ACCOUNT') {
                errorMessage = kairos_wp_get_message('error-domain-already-registered-by-other') || 'This website domain is already registered to another Kairos WP account.';
            } else if (error?.data?.error === 'DOMAIN_ASSOCIATION_FAILED') {
                errorMessage = kairos_wp_get_message('error-domain-association-failed') || 'Could not associate this website domain with your account.';
            } else if (error?.data?.error === 'MISSING_CURRENT_DOMAIN') {
                errorMessage = kairos_wp_get_message('error-missing-current-domain') || 'Critical error: Current domain was not sent to the server.';
            } else if (error?.status === 504 || (error?.data?.message && error.data.message.toLowerCase().includes('timeout'))) {
                errorMessage = kairos_wp_get_message('error-api-timeout');
            } else if (error?.message && (error.message.toLowerCase().includes('networkerror') || error.message.toLowerCase().includes('failed to fetch'))) {
                errorMessage = kairos_wp_get_message('error-network');
            } else if (error?.data?.error) {
                 errorMessage = `${kairos_wp_get_message('error-api-generic')} (Detalle: ${error.data.error})`;
            } else if (error?.message) {
                 errorMessage = `${kairos_wp_get_message('error-api-generic')} (Detalle: ${error.message})`;
            }
			$( '#kairos-wp-alert-popup-overlay' ).fadeIn();
			$( '#kairos-wp-alert-text' ).text(errorMessage);
        } finally {
            // $spinner.hide(); // Reemplazado por ThickBox
            if (typeof window.hideThickboxLoader === 'function') window.hideThickboxLoader();
			// Only re-enable the button if the operation failed
            if (!operationSuccessful) {
                 const isAuthenticated = await checkAuthStateForCPT(); // Re-check auth
                 const hasImpText = $improvementsTextarea.val().trim().length > 0; // Check if text remains
                 $button.prop('disabled', !(isAuthenticated && hasImpText));
            }
            // If successful, the button remains disabled because the textarea was cleared in the try block.
        }
	});

    // Handle "View Code" buttons
	$( document ).on( 'click', '.kairos-wp-view-code-btn', function(e) {
		e.preventDefault();
		var type = $(this).data('type');
		var code = $( '#kairos-wp-hidden-' + type ).text();
		var title = $(this).text();
		if (code && code.trim()) {
			$( '#kairos-wp-code-modal-title' ).text( title );
			$( '#kairos-wp-code-modal-content' ).text( code );
			$( '#kairos-wp-code-modal' ).css('display', 'flex');
		} else {
			$( '#kairos-wp-alert-popup-overlay' ).fadeIn();
			$( '#kairos-wp-alert-text' ).text( (kairos_wp_get_message( "cpt-error-no-code-type-fallback" ) || 'No %s code available to view.').replace('%s', type.toUpperCase()) );
		}
	});

    // Handle "Mark as Finished" button click (Confirmation Yes part)
    $( '#kairos-wp-confirm-yes' ).off('click').on('click', function() {
        const $confirmPopup = $( '#kairos-wp-confirm-popup-overlay' );
        const $markFinishedButton = $('.kairos-wp-delivery-screen .button-secondary:contains("Mark as Finished")');
        $confirmPopup.fadeOut();
        $markFinishedButton.prop('disabled', true);
        $( '#kairos-wp-loader-overlay' ).fadeIn();

        // Use direct $.ajax
        $.ajax({
            url: ajaxUrl,
            type: 'POST',
            data: {
                action: 'kairos_wp_mark_as_finished', // Use correct action
                nonce: nonce,
                post_id: postID
            },
            success: function(response) {
                if (response.success) {
                     $markFinishedButton.closest('.kairos-wp-delivery-actions').append(`<div class="notice notice-success inline" style="margin-left: 10px; padding: 5px 10px;"><p><strong>${kairos_wp_get_message('success-plugin-marked-completed-inline') || 'Plugin marked as completed!'}</strong></p></div>`);
                     $markFinishedButton.prop('disabled', true).text(kairos_wp_get_message('button-completed') || 'Completed');
                     // Optional: Redirect after a short delay?
                     // setTimeout(function() { window.location.href = response.data.redirect_url; }, 1500);
                } else {
                     console.error("Failed to mark as finished:", response.data);
                     $( '#kairos-wp-alert-popup-overlay' ).fadeIn();
                     $( '#kairos-wp-alert-text' ).text( response.data?.message || kairos_wp_get_message('error-general') );
                     $markFinishedButton.prop('disabled', false); // Re-enable on error
                }
            },
            error: function(jqXHR, textStatus, errorThrown) {
                 console.error("AJAX error marking as finished:", textStatus, errorThrown);
                 $( '#kairos-wp-alert-popup-overlay' ).fadeIn();
                 $( '#kairos-wp-alert-text' ).text( kairos_wp_get_message('error-general') );
                 $markFinishedButton.prop('disabled', false); // Re-enable on error
            },
            complete: function() {
                $( '#kairos-wp-loader-overlay' ).fadeOut();
            }
        });
    });


    // --- Initial Setup on CPT Screen Load ---
	if ( $('body').hasClass('post-type-kairos_wp') && ($('body').hasClass('post-php') || $('body').hasClass('post-new-php')) ) {

		// --- Button Enable/Disable Logic ---

		// 1. Initial Lola Button (Send Idea)
        // Variables $initialPromptTextarea and $sendToLolaButton are now declared at the top level of the IIFE

		// Function to update Lola button state based on auth and text
		const updateLolaButtonState = async () => {
			const isAuthenticated = await checkAuthStateForCPT(); // Check auth status first
			const hasText = $initialPromptTextarea.val().trim().length > 0;
			$sendToLolaButton.prop('disabled', !(isAuthenticated && hasText));
		};

		// Initial check and listener setup for initial Lola button
		if ($initialPromptTextarea.length && $sendToLolaButton.length) {
			// Run initial check AFTER the main auth check completes
			checkAuthStateForCPT().then(() => {
				updateLolaButtonState(); // Set initial state based on auth and text
			});
			// Listener for initial Lola button (Re-check auth and text on input)
			$initialPromptTextarea.on('input', updateLolaButtonState);
		} else {
            // If elements not found, run the auth check anyway to potentially disable other buttons
            checkAuthStateForCPT();
        }

		// 2. Improvements Lola Button (Refine Improvements)
        // Variables $improvementsTextarea and $sendImprovementsButton are now declared at the top level of the IIFE

		// Initial check for improvements Lola button
		if ($improvementsTextarea.length && $sendImprovementsButton.length) {
			// Check auth state and enable if authenticated, regardless of textarea content initially
			checkAuthStateForCPT().then(isAuthenticated => {
				if (isAuthenticated) {
					// Enable button only if authenticated AND textarea has content
                    const hasImpText = $improvementsTextarea.val().trim().length > 0;
					$sendImprovementsButton.prop('disabled', !hasImpText);
				} else {
					$sendImprovementsButton.prop('disabled', true); // Keep disabled if not authenticated
				}
			});

			// Listener for improvements Lola button - Disable if textarea becomes empty OR not authenticated
			$improvementsTextarea.on('input', function() {
                const hasImpText = $(this).val().trim().length > 0;
                // Re-check auth state on input as well
                checkAuthStateForCPT().then(isAuthenticated => {
                    $sendImprovementsButton.prop('disabled', !(isAuthenticated && hasImpText));
                });
			});
		}
		// --- End Button Enable/Disable Logic ---

        // Initial call to update token metabox display based on saved meta
        // This requires the meta values to be available in kairos_wp_object
        if (typeof kairos_wp_object !== 'undefined' && kairos_wp_object.token_meta && typeof window.updateTokenMetaboxDisplay === 'function') {
             window.updateTokenMetaboxDisplay(kairos_wp_object.token_meta); // Use globally exposed function
        } else {
             console.warn("[CPT Screen] Token meta data not found in localized object or updateTokenMetaboxDisplay not found for initial display.");
        }

	} // End CPT screen check

})(jQuery); // End IIFE
