<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-core.php';
require_once plugin_dir_path( __DIR__ ) . '/framework/includes/class-kairos-wp-ajax-framework.php';

class Kairos_WP_Ajax extends Kairos_WP_Ajax_Framework {
	public $core;

	public function __construct() {
		$this->core = new Kairos_WP_Core();
	}

	/**
	 * Handles the AJAX request to get the user's token quota status from Vercel.
	 */
	public function kairos_wp_get_token_quota_proxy() {
		// 1. Security Checks (Nonce and Login)
		if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'kairos_wp_nonce' ) ) {
			wp_send_json_error( array( 'message' => __( 'Nonce verification failed.', 'kairos-wp' ) ), 403 );
			wp_die();
		}
		if ( ! is_user_logged_in() ) {
			wp_send_json_error( array( 'message' => __( 'User not logged in.', 'kairos-wp' ) ), 403 );
			wp_die();
		}

        // 2. Get JWT from Authorization Header (Sent by JS)
        $auth_header = isset( $_SERVER['HTTP_AUTHORIZATION'] ) ? sanitize_text_field( wp_unslash( $_SERVER['HTTP_AUTHORIZATION'] ) ) : '';
        $jwt_token = '';
        if ( preg_match( '/Bearer\s(\S+)/', $auth_header, $matches ) ) {
            $jwt_token = $matches[1];
        }

        if ( empty( $jwt_token ) ) {
             if (isset($_POST['jwt_token'])) {
                 $jwt_token = sanitize_text_field(wp_unslash($_POST['jwt_token']));
             } else {
                wp_send_json_error( array( 'message' => __( 'Authentication token missing.', 'kairos-wp' ) ), 401 );
                wp_die();
             }
        }

		// 3. Prepare request to Vercel
		$vercel_get_quota_url = 'https://kairos-wp.vercel.app/api/auth?action=get-quota';
		$request_args = array(
			'method'  => 'GET',
			'headers' => array( 'Authorization' => 'Bearer ' . $jwt_token ),
			'timeout' => 20,
		);

		// 4. Call Vercel Endpoint
		$response = wp_remote_get( $vercel_get_quota_url, $request_args );

		// 5. Process Response
		if ( is_wp_error( $response ) ) {
			error_log( '[Kairos WP Ajax] WP Error calling Vercel (get-quota): ' . $response->get_error_message() );
			wp_send_json_error( array( 'message' => __( 'Error communicating with account server (WP).', 'kairos-wp' ) ), 500 );
			wp_die();
		}

		$response_code = wp_remote_retrieve_response_code( $response );
		$response_body = wp_remote_retrieve_body( $response );
		$decoded_body  = json_decode( $response_body, true );

		if ( $response_code >= 200 && $response_code < 300 && isset( $decoded_body['success'] ) && $decoded_body['success'] === true && isset( $decoded_body['data']['limit'], $decoded_body['data']['consumed'] ) ) {
			wp_send_json_success( array(
                'limit' => intval($decoded_body['data']['limit']),
                'consumed' => intval($decoded_body['data']['consumed'])
            ) );
		} else {
            $error_message = __( 'Unknown error retrieving quota status.', 'kairos-wp' );
            if (isset($decoded_body['message'])) {
                // Prioritize specific message from Vercel if it's likely user-facing
                // However, for security, some Vercel messages might not be ideal to show directly.
                // For now, we'll allow it, but this could be refined to map Vercel error codes to translated strings.
                $error_message = $decoded_body['message']; 
            } elseif (isset($decoded_body['error'])) {
                 $error_message = is_string($decoded_body['error']) ? $decoded_body['error'] : __( 'API Error (non-string)', 'kairos-wp' );
            }

            if ($response_code === 404) $error_message = __( 'Account service endpoint not found or user profile missing.', 'kairos-wp' );
            elseif ($response_code === 401 || $response_code === 403) $error_message = __( 'Authentication failed. Please log in again.', 'kairos-wp' );
            elseif ($response_code >= 500) $error_message = __( 'Account server error. Please try again later.', 'kairos-wp' );
			error_log( '[Kairos WP Ajax] Error from Vercel (get-quota) (' . $response_code . '): ' . $error_message . ' | Raw Body: ' . $response_body );
			wp_send_json_error( array( 'message' => $error_message, 'code' => $response_code ), $response_code );
		}
		wp_die();
	}

	private function security_check( $action_name = 'kairos_wp_nonce', $check_post_id = true ) {
		if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), $action_name ) ) {
			wp_send_json_error( array( 'message' => __( 'Nonce verification failed.', 'kairos-wp' ) ), 403 );
			wp_die();
		}
		if ( ! current_user_can( 'edit_posts' ) ) {
			wp_send_json_error( array( 'message' => __( 'Insufficient permissions.', 'kairos-wp' ) ), 403 );
			wp_die();
		}
		if ( $check_post_id ) {
            if ( ! isset( $_POST['post_id'] ) ) {
                wp_send_json_error( array( 'message' => __( 'Missing post ID.', 'kairos-wp' ) ), 400 );
                wp_die();
            }
            return intval( $_POST['post_id'] );
        }
        return null;
	}

    private function get_updated_token_metas( $post_id ) {
        return [
            'lola_initial' => get_post_meta( $post_id, '_lola_initial_total_tokens', true ) ?: '0',
            'lola_refine'  => get_post_meta( $post_id, '_lola_refine_total_tokens', true ) ?: '0',
            'pablo'        => get_post_meta( $post_id, '_pablo_total_tokens', true ) ?: '0',
            'alex'         => get_post_meta( $post_id, '_alex_total_tokens', true ) ?: '0',
            'cumulative'   => get_post_meta( $post_id, '_total_tokens_cumulative', true ) ?: '0',
        ];
    }

    private function clear_old_code_metas( $post_id ) {
        update_post_meta( $post_id, '_code_not_generated', '1' );
        delete_post_meta( $post_id, '_php_output' );
        delete_post_meta( $post_id, '_js_output' );
        delete_post_meta( $post_id, '_css_output' );
        delete_post_meta( $post_id, '_confidence_level' );
        delete_post_meta( $post_id, '_confidence_level_explanation' );
        delete_post_meta( $post_id, '_suggestions' );
        delete_post_meta( $post_id, '_confidence_generation' );
    }

    public function kairos_wp_handle_save_initial_lola() {
        $post_id = $this->security_check();
        if ( ! isset( $_POST['functional_requirements'], $_POST['lola_initial_tokens'] ) ) {
            wp_send_json_error( array( 'message' => __( 'Missing required data for initial save.', 'kairos-wp' ) ), 400 );
            wp_die(); // Ensure script termination
        }
        $requirements = wp_kses_post( wp_unslash( $_POST['functional_requirements'] ) );
        $lola_tokens  = ( is_numeric( $_POST['lola_initial_tokens'] ) && $_POST['lola_initial_tokens'] >= 0 ) ? intval( $_POST['lola_initial_tokens'] ) : 0;
        update_post_meta( $post_id, '_functional_requirements', $requirements );
        update_post_meta( $post_id, '_lola_initial_total_tokens', (string) $lola_tokens );
        update_post_meta( $post_id, '_lola_refine_total_tokens', '0' );
        update_post_meta( $post_id, '_pablo_total_tokens', '0' );
        update_post_meta( $post_id, '_alex_total_tokens', '0' );
        update_post_meta( $post_id, '_total_tokens_cumulative', (string) $lola_tokens );
        update_post_meta( $post_id, '_code_not_generated', '1' );
        update_post_meta( $post_id, '_lola_refined', '1' );
        $this->clear_old_code_metas($post_id);

        // Force post save to persist meta
        $post_array = array('ID' => $post_id);
        $updated_post_id = wp_update_post($post_array, true);
        if (is_wp_error($updated_post_id)) {
            error_log('[Kairos WP Ajax DEBUG] Failed to programmatically save post ' . $post_id . ' in kairos_wp_handle_save_initial_lola. Error: ' . $updated_post_id->get_error_message());
        } else {
            error_log('[Kairos WP Ajax DEBUG] Programmatically saved post ' . $post_id . ' in kairos_wp_handle_save_initial_lola');
        }

        wp_send_json_success( array( 'message' => __( 'Initial requirements saved.', 'kairos-wp' ), 'updated_token_metas' => $this->get_updated_token_metas( $post_id ) ) );
        wp_die();
    }

    public function kairos_wp_handle_save_pablo_results() {
        $post_id = $this->security_check();
        if ( ! isset( $_POST['php_output'], $_POST['js_output'], $_POST['css_output'], $_POST['pablo_tokens'] ) ) {
            wp_send_json_error( array( 'message' => __( 'Missing required data for saving Pablo results.', 'kairos-wp' ) ), 400 );
            wp_die(); // Ensure script termination
        }

        // MODIFICACIÓN: Usar solo wp_unslash para el código PHP para preservar la cabecera.
        // Se asume que el código de la API es seguro o se sanitiza en origen si es necesario.
        $php_code     = wp_unslash( $_POST['php_output'] ); 
        $js_code_from_post = wp_unslash( $_POST['js_output'] ); // Keep unslashed for logging, kses_post later
        $css_code_from_post = wp_unslash( $_POST['css_output'] ); // Keep unslashed for logging, kses_post later
        $pablo_tokens = ( is_numeric( $_POST['pablo_tokens'] ) && $_POST['pablo_tokens'] >= 0 ) ? intval( $_POST['pablo_tokens'] ) : 0;

        error_log('[Kairos WP Ajax DEBUG] kairos_wp_handle_save_pablo_results - Received JS length: ' . strlen($js_code_from_post));
        error_log('[Kairos WP Ajax DEBUG] kairos_wp_handle_save_pablo_results - Received CSS length: ' . strlen($css_code_from_post));

        // Sanitize before saving
        $js_code  = wp_kses_post( $js_code_from_post );
        $css_code = wp_kses_post( $css_code_from_post );

        $php_save_result = update_post_meta( $post_id, '_php_output', $php_code );
        $js_save_result = update_post_meta( $post_id, '_js_output', $js_code );
        $css_save_result = update_post_meta( $post_id, '_css_output', $css_code );

        error_log('[Kairos WP Ajax DEBUG] kairos_wp_handle_save_pablo_results - PHP save result: ' . ($php_save_result ? 'Success/Same' : 'Failed/Changed'));
        error_log('[Kairos WP Ajax DEBUG] kairos_wp_handle_save_pablo_results - JS save result: ' . ($js_save_result ? 'Success/Same' : 'Failed/Changed'));
        error_log('[Kairos WP Ajax DEBUG] kairos_wp_handle_save_pablo_results - CSS save result: ' . ($css_save_result ? 'Success/Same' : 'Failed/Changed'));
        
        $existing_pablo_tokens = get_post_meta( $post_id, '_pablo_total_tokens', true ) ?: '0';
        $new_pablo_total_tokens = intval( $existing_pablo_tokens ) + $pablo_tokens;
        update_post_meta( $post_id, '_pablo_total_tokens', (string) $new_pablo_total_tokens );
        update_post_meta( $post_id, '_code_not_generated', '0' );
        $lola_initial = get_post_meta( $post_id, '_lola_initial_total_tokens', true ) ?: '0';
        $lola_refine  = get_post_meta( $post_id, '_lola_refine_total_tokens', true ) ?: '0';
        $new_cumulative = intval($lola_initial) + intval($lola_refine) + $new_pablo_total_tokens;
        update_post_meta( $post_id, '_total_tokens_cumulative', (string) $new_cumulative );

        // Post should have been published by kairos_wp_publish_cpt_before_pablo.
        // This call to wp_update_post is just to ensure meta fields are saved with the current post state.
        $post_array = array('ID' => $post_id); // No longer changing post_status here
        $updated_post_id = wp_update_post($post_array, true); // true for WP_Error on failure

        if (is_wp_error($updated_post_id)) {
            error_log('[Kairos WP Ajax DEBUG] Failed to programmatically save post ' . $post_id . ' (after Pablo results, post should be published). Error: ' . $updated_post_id->get_error_message());
        } else {
            error_log('[Kairos WP Ajax DEBUG] Programmatically saved post ' . $post_id . ' (after Pablo results, post should be published).');
        }

        wp_send_json_success( array( 'message' => __( 'Pablo\'s results saved to published plugin.', 'kairos-wp' ), 'updated_token_metas' => $this->get_updated_token_metas( $post_id ) ) );
        wp_die();
    }

    public function kairos_wp_handle_save_alex_review() {
        $post_id = $this->security_check();
        if ( ! isset( $_POST['confidence_level'], $_POST['explanation'], $_POST['suggestions'], $_POST['alex_tokens'] ) ) {
            wp_send_json_error( array( 'message' => __( 'Missing required data for saving Alex review.', 'kairos-wp' ) ), 400 );
            wp_die(); // Ensure script termination
        }
        $confidence = is_numeric($_POST['confidence_level']) ? (string) floatval($_POST['confidence_level']) : '';
        $explanation = wp_kses_post( wp_unslash( $_POST['explanation'] ) );
        $suggestions = is_string($_POST['suggestions']) ? wp_unslash($_POST['suggestions']) : '[]';
        $alex_tokens = ( is_numeric( $_POST['alex_tokens'] ) && $_POST['alex_tokens'] >= 0 ) ? intval( $_POST['alex_tokens'] ) : 0;
        if (json_decode($suggestions) === null && json_last_error() !== JSON_ERROR_NONE) $suggestions = '[]';
        update_post_meta( $post_id, '_confidence_level', $confidence );
        update_post_meta( $post_id, '_confidence_level_explanation', $explanation );
        update_post_meta( $post_id, '_suggestions', $suggestions );
        $existing_alex_tokens = get_post_meta( $post_id, '_alex_total_tokens', true ) ?: '0';
        $new_alex_total_tokens = intval( $existing_alex_tokens ) + $alex_tokens;
        update_post_meta( $post_id, '_alex_total_tokens', (string) $new_alex_total_tokens );
        $lola_initial = get_post_meta( $post_id, '_lola_initial_total_tokens', true ) ?: '0';
        $lola_refine  = get_post_meta( $post_id, '_lola_refine_total_tokens', true ) ?: '0';
        $pablo        = get_post_meta( $post_id, '_pablo_total_tokens', true ) ?: '0';
        $new_cumulative = intval($lola_initial) + intval($lola_refine) + intval($pablo) + $new_alex_total_tokens;
        update_post_meta( $post_id, '_total_tokens_cumulative', (string) $new_cumulative );

        // Force post save to persist meta
        $post_array = array('ID' => $post_id);
        $updated_post_id = wp_update_post($post_array, true);
        if (is_wp_error($updated_post_id)) {
            error_log('[Kairos WP Ajax DEBUG] Failed to programmatically save post ' . $post_id . ' in kairos_wp_handle_save_alex_review. Error: ' . $updated_post_id->get_error_message());
        } else {
            error_log('[Kairos WP Ajax DEBUG] Programmatically saved post ' . $post_id . ' in kairos_wp_handle_save_alex_review');
        }

        wp_send_json_success( array( 'message' => __( 'Alex\'s review saved.', 'kairos-wp' ), 'updated_token_metas' => $this->get_updated_token_metas( $post_id ) ) );
        wp_die();
    }

    public function kairos_wp_handle_save_refined_lola() {
        $post_id = $this->security_check();
        if ( ! isset( $_POST['functional_requirements'], $_POST['lola_refine_tokens'] ) ) {
             wp_send_json_error( array( 'message' => __( 'Missing required data for saving refined requirements.', 'kairos-wp' ) ), 400 );
             wp_die(); // Ensure script termination
        }
        $requirements = wp_kses_post( wp_unslash( $_POST['functional_requirements'] ) );
        $lola_tokens  = ( is_numeric( $_POST['lola_refine_tokens'] ) && $_POST['lola_refine_tokens'] >= 0 ) ? intval( $_POST['lola_refine_tokens'] ) : 0;
        update_post_meta( $post_id, '_functional_requirements', $requirements );
        update_post_meta( $post_id, '_lola_refine_total_tokens', (string) $lola_tokens );
        $pablo_actual = get_post_meta( $post_id, '_pablo_total_tokens', true ) ?: '0';
        $alex_actual  = get_post_meta( $post_id, '_alex_total_tokens', true ) ?: '0';
        $this->clear_old_code_metas($post_id);
        $lola_initial = get_post_meta( $post_id, '_lola_initial_total_tokens', true ) ?: '0';
        $new_cumulative = intval($lola_initial) + $lola_tokens + intval($pablo_actual) + intval($alex_actual);
        update_post_meta( $post_id, '_total_tokens_cumulative', (string) $new_cumulative );

        // Force post save to persist meta
        $post_array = array('ID' => $post_id);
        $updated_post_id = wp_update_post($post_array, true);
        if (is_wp_error($updated_post_id)) {
            error_log('[Kairos WP Ajax DEBUG] Failed to programmatically save post ' . $post_id . ' in kairos_wp_handle_save_refined_lola. Error: ' . $updated_post_id->get_error_message());
        } else {
            error_log('[Kairos WP Ajax DEBUG] Programmatically saved post ' . $post_id . ' in kairos_wp_handle_save_refined_lola');
        }

        wp_send_json_success( array( 'message' => __( 'Refined requirements saved.', 'kairos-wp' ), 'updated_token_metas' => $this->get_updated_token_metas( $post_id ) ) );
        wp_die();
    }

    public function kairos_wp_handle_save_manual_edit() {
        $post_id = $this->security_check();
        if ( ! isset( $_POST['edited'] ) || !isset($_POST['type']) || $_POST['type'] !== 'functional-requirements' ) {
             wp_send_json_error( array( 'message' => __( 'Missing or invalid data for manual edit.', 'kairos-wp' ) ), 400 );
             wp_die(); // Ensure script termination
        }
        $requirements = wp_kses_post( wp_unslash( $_POST['edited'] ) );
        update_post_meta( $post_id, '_functional_requirements', $requirements );
        $this->clear_old_code_metas($post_id);
        update_post_meta( $post_id, '_lola_initial_total_tokens', '0' );
        update_post_meta( $post_id, '_lola_refine_total_tokens', '0' );
        update_post_meta( $post_id, '_total_tokens_cumulative', '0' );

        // Force post save to persist meta
        $post_array = array('ID' => $post_id);
        $updated_post_id = wp_update_post($post_array, true);
        if (is_wp_error($updated_post_id)) {
            error_log('[Kairos WP Ajax DEBUG] Failed to programmatically save post ' . $post_id . ' in kairos_wp_handle_save_manual_edit. Error: ' . $updated_post_id->get_error_message());
        } else {
            error_log('[Kairos WP Ajax DEBUG] Programmatically saved post ' . $post_id . ' in kairos_wp_handle_save_manual_edit');
        }

        wp_send_json_success( array( 'message' => __( 'Manual requirements saved.', 'kairos-wp' ), 'updated_token_metas' => $this->get_updated_token_metas( $post_id ) ) );
        wp_die();
    }

    // New function to publish CPT before sending to Pablo
    public function kairos_wp_publish_cpt_before_pablo() {
        $post_id = $this->security_check(); 

        if ( ! $post_id ) {
            // security_check sends json error and dies if post_id is missing
            return; 
        }

        $current_post = get_post($post_id);
        if (!$current_post) {
            error_log('[Kairos WP Ajax DEBUG] kairos_wp_publish_cpt_before_pablo - Post not found: ' . $post_id);
            wp_send_json_error( array( 'message' => __( 'Error: Post not found for publishing.', 'kairos-wp' ) ), 404 );
            wp_die();
        }

        // Only proceed if post is not already published
        if ($current_post->post_status !== 'publish') {
            $post_array = array(
                'ID'            => $post_id,
                'post_status'   => 'publish'
            );
            $updated_post_id = wp_update_post($post_array, true); // true for WP_Error on failure

            if (is_wp_error($updated_post_id)) {
                error_log('[Kairos WP Ajax DEBUG] Failed to programmatically publish post ' . $post_id . ' before sending to Pablo. Error: ' . $updated_post_id->get_error_message());
                wp_send_json_error( array( 'message' => __( 'Error publishing post before generation.', 'kairos-wp' ) ), 500 );
            } else {
                error_log('[Kairos WP Ajax DEBUG] Programmatically published post ' . $post_id . ' before sending to Pablo.');
                wp_send_json_success( array( 'message' => __( 'Post published successfully before generation.', 'kairos-wp' ) ) );
            }
        } else {
            // Post is already published, no action needed, send success
            error_log('[Kairos WP Ajax DEBUG] Post ' . $post_id . ' is already published. No status change needed before sending to Pablo.');
            wp_send_json_success( array( 'message' => __( 'Post already published.', 'kairos-wp' ) ) );
        }
        wp_die();
    }

	public function kairos_wp_handle_save_to_plugins() {
		error_log('[Kairos WP Ajax DEBUG] Entered kairos_wp_handle_save_to_plugins');
		if ( isset( $_POST['php_code'], $_POST['js_code'], $_POST['css_code'], $_POST['post_id'] ) ) {
			if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'kairos_wp_nonce' )
			|| ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) ) {
				error_log('[Kairos WP Ajax DEBUG] Nonce/Autosave check failed in save_to_plugins');
				wp_send_json_error( 'error-unauthorized-access' );
				wp_die();
			}

			$user = wp_get_current_user();
			if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || ! in_array( 'administrator', $user->roles ) ) {
				error_log('[Kairos WP Ajax DEBUG] Permissions check failed in save_to_plugins');
				wp_send_json_error( 'error-unauthorized-access' );
				wp_die();
			}

            // MODIFICATION: Get code from post meta instead of $_POST
            $post_id     = intval( sanitize_text_field( wp_unslash( $_POST['post_id'] ) ) ); // Keep post_id from POST for context
            $php_code    = get_post_meta( $post_id, '_php_output', true );
            $js_code     = get_post_meta( $post_id, '_js_output', true );
            $css_code    = get_post_meta( $post_id, '_css_output', true );

            // Fallback or ensure they are strings if meta not found or empty
            $php_code = !empty($php_code) ? $php_code : '';
            $js_code  = !empty($js_code) ? $js_code : '';
            $css_code = !empty($css_code) ? $css_code : '';

			$post        = get_post( $post_id );
			$folder_name = sanitize_title( $post->post_name );

			error_log('[Kairos WP Ajax DEBUG] save_to_plugins - Post ID: ' . $post_id);
			error_log('[Kairos WP Ajax DEBUG] save_to_plugins - Folder name: ' . $folder_name);
			error_log('[Kairos WP Ajax DEBUG] save_to_plugins - PHP code length from meta: ' . strlen($php_code));
			error_log('[Kairos WP Ajax DEBUG] save_to_plugins - JS code length from meta: ' . strlen($js_code));
			error_log('[Kairos WP Ajax DEBUG] save_to_plugins - CSS code length from meta: ' . strlen($css_code));

			$plugins_dir = WP_PLUGIN_DIR;
			$folder_path = $plugins_dir . '/' . $folder_name;
			// Use the folder name for the main PHP file as well for consistency
			$php_file    = $folder_path . '/' . $folder_name . '.php'; 
			
			// JS/CSS files in the root of the plugin folder
			$js_file     = $folder_path . '/script.js'; 
			$css_file    = $folder_path . '/style.css'; 

			global $wp_filesystem;
			if ( empty( $wp_filesystem ) ) {
				WP_Filesystem();
			}

			// Ensure plugin main folder exists
			if ( ! $wp_filesystem->exists( $folder_path ) ) {
				error_log('[Kairos WP Ajax DEBUG] Creating plugin folder: ' . $folder_path);
				$wp_filesystem->mkdir( $folder_path );
			}
			// No longer creating assets subdirectories here, files go to root.
			
			$exists = $wp_filesystem->exists( $php_file );
			if ( $exists ) {
				$old_content = $wp_filesystem->get_contents( $php_file );
			}

			$plugin_header = "<?php
			/**
			 * Plugin Name: {$folder_name} Temporary Plugin
			 * Description: Empty Plugin while checking for errors is in process.
			 * Author: Kairos WP
			 * Version: 1.0
			 */
			?>";
			// Ensure $php_file uses the new naming convention if $plugin_header is written to it first
			$wp_filesystem->put_contents( $php_file, $plugin_header, FS_CHMOD_FILE ); 
			wp_cache_flush();

			$save_response = null;
			$save_bool     = false;
			if ( is_multisite() ) {
				$save_response = 'error-save-multisite';
				$save_bool     = true;
			} else {
				$active = is_plugin_active( $php_file );
				if ( ! is_plugin_active( $php_file ) ) {
					activate_plugin( $php_file );
				}

				$args               = array();
				// $args['file'] should match the actual main file name of the plugin being edited/checked
				$args['file']       = $folder_name . '/' . $folder_name . '.php'; 
				$args['plugin']     = $args['file'];
				$args['newcontent'] = $php_code;
				$args['nonce']      = wp_create_nonce( 'edit-plugin_' . $args['file'] );
				$activate = wp_edit_theme_plugin_file( $args );

				if ( ! is_wp_error( $activate ) ) {
					error_log('[Kairos WP Ajax DEBUG] PHP activation successful. Writing JS/CSS.');
					$js_write_success = $wp_filesystem->put_contents( $js_file, $js_code, FS_CHMOD_FILE );
					$css_write_success = $wp_filesystem->put_contents( $css_file, $css_code, FS_CHMOD_FILE );
					error_log('[Kairos WP Ajax DEBUG] JS write success: ' . ($js_write_success ? 'true' : 'false') . ' to ' . $js_file);
					error_log('[Kairos WP Ajax DEBUG] CSS write success: ' . ($css_write_success ? 'true' : 'false') . ' to ' . $css_file);
					$save_response = 'success-save';
					$save_bool     = true;
				} elseif ( 'loopback_request_failed' === $activate->error_data['php_error']['code'] ) {
						$save_response = 'error-save-loopback';
						$save_bool     = true;
				} else {
					$error         = wp_json_encode( $activate->errors );
					$line          = $activate->error_data['php_error']['line'];
					$save_response = array( 'code'  => 'error-save-php', 'error' => $error, 'line'  => $line );
					$save_bool     = false;
				}
			}

			if ( $exists ) {
				$wp_filesystem->put_contents( $php_file, $old_content, FS_CHMOD_FILE );
				if ( isset( $active ) && ! $active ) deactivate_plugins( $php_file );
			} else {
				wp_delete_file( $php_file );
				$wp_filesystem->rmdir( $folder_path ); // Consider not removing if assets were created
			}

			if ( true === $save_bool ) wp_send_json_success( $save_response );
			else wp_send_json_error( $save_response );
		} else {
			error_log('[Kairos WP Ajax DEBUG] Missing POST data in save_to_plugins');
			wp_send_json_error( 'error-isset-post' );
		}
		wp_die();
	}

	private function handle_mark_as_finished() {
		if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'kairos_wp_nonce' ) ) {
			wp_send_json_error( array( 'message' => __( 'Nonce verification failed.', 'kairos-wp' ) ), 403 );
		}
		if ( ! current_user_can( 'edit_posts' ) ) {
			wp_send_json_error( array( 'message' => __( 'Insufficient permissions.', 'kairos-wp' ) ), 403 );
		}
		if ( ! isset( $_POST['post_id'] ) ) {
			wp_send_json_error( array( 'message' => __( 'Missing post ID.', 'kairos-wp' ) ), 400 );
		}
		$post_id = intval( $_POST['post_id'] );
		$post = get_post( $post_id );
		if ( ! $post || 'kairos_wp' !== $post->post_type ) {
			wp_send_json_error( array( 'message' => __( 'Invalid post.', 'kairos-wp' ) ), 404 );
		}
		$post_data = array( 'ID' => $post_id, 'post_status' => 'publish' );
		$update_result = wp_update_post( $post_data, true );
		if ( is_wp_error( $update_result ) ) {
			error_log("[Kairos WP Ajax] Failed to update post status for ID: " . $post_id . " - Error: " . $update_result->get_error_message());
			wp_send_json_error( array( 'message' => __( 'Error updating post status to published.', 'kairos-wp' ), 'error_details' => $update_result->get_error_message() ), 500 );
		} else {
			wp_send_json_success( array( 'message' => __( 'Plugin marked as finished.', 'kairos-wp' ), 'redirect_url' => admin_url( 'admin.php?page=kairos-wp-settings' ) ) );
		}
		wp_die();
	}

	public function kairos_wp_handle_mark_as_finished() {
		$this->handle_mark_as_finished();
	}

} // End of Kairos_WP_Ajax class
